/*
JMP Clinical Analytical Process

Name: Advere Events Report
Authors: SASLII, SAS Institute Inc.

Description: 
   This process creates static reports of adverse events.  
*/

/*
-----------------------------------------------------------
Copyright (C) 2010 SAS Institute, Inc. All rights reserved. 

Notice: 
The above copyright notice and this notice must appear in
any whole or partial copy of this code and any related
documentation. Permission to use, copy, and modify the
source code contained in this file is hereby granted, but
is limited to customers of SAS with a valid license for the
SAS software product with which this file was provided. 
Except as expressly set forth herein, the terms of such
license apply.
-----------------------------------------------------------
*/

************************************************************************;
*     Clinical Variable Specification Block of AdverseEventsReport Variable Usage;
************************************************************************;
/* 
$CVS_START$
$INCF: {"LifeSciences\MacroLib\CDISCParms.sas","LifeSciences\MacroLib\DomainDistribution.sas"}$
$INCB: {{"EventsO","CrossoverPeriods","AETermValues","TreatmentEmergentEvents"},{"ADSLDistributionOptions"}}$
$INCD: {"AE",{""}}$
$CMP: CPV.{"Include serious adverse events only","Yes"}$ $UE: AE.AESER$ $NOTES: Only records with AESER = Y will be kept in analysis.$
$CMP: RSYS$ $UE: AE.AEDECOD or AE.AETERM$ $NOTES: either the AEDECOD or the AETERM variables will be used for AE Event occurrence.$
$CMP: OSYS$ $UE: DM.SEX$ $NOTES: Used to calculate counts by their sex.$ 
$CMP: OSYS$ $UE: DM.RACE$ $NOTES: Used to calculate counts by their race.$ 
$CMP: OOUT$ $UE: AE.AESEV or AE.AETOXGR$ $NOTES: Used to categorize events by severity/toxicity.$ 
$CMP: OOUT$ $UE: AE.AEOUT$ $NOTES: Used to categorize events by their outcome.$ 
$CMP: OOUT$ $UE: AE.AESER$ $NOTES: Used to calculate counts by categorizing by serious events.$
$CMP: OOUT$ $UE: AE.AEREL$ $NOTES: Used to calculate counts by causality.$ 
$CMP: OOUT$ $UE: AE.AEOUT$ $NOTES: Used to calculate counts by their outcome.$ 
$CVS_STOP$
*/


*ProcessVariables;

%global StudyName InPath AInPath TrtVar TrtUse AESerCount MergeSuppDom
IncSF PopulationSet DesignByVars 
SubjectFilter WhereStmt AEWhereStmt AESerOnly TEAEOnly OutPath ServerOutPath 
CountMultiple OutName MacroPath Output_RTF Output_PDF Output_HTML Output_Text PropThresh
AEDistributionReport_Body AEDistributionReport_Contents AEDistributionReport_Frame
AdverseEventsReportScript AdverseEventsReportScriptName TrtOffSet IgnoreTEAEFlags EXENDTCFl
;

*ProcessBody;

%macro AdverseEventsReport;
   * options mprint;
   *initialization and argument checking;
   %let ProcessName = AdverseEventsReport; 
  
   %include "&MacroPath./UtilityMacros.sas" / nosource;
   %include "&MacroPath./CDISCParms.sas";
   %if &exiterror %then %goto exit;

   %if &Output_RTF = No and &Output_PDF = No %then %do;
      %put [MS_S_0010];
      %put ERROR: At least one output format must be selected.;
      %let exiterror = 1;
      %goto exit;
   %end;
   
   %if ^%sysfunc(findw(&domains, AE)) %then %do;
      %put [MS_S_0011];
      %put ERROR: The AE or ADAE data set does not exist for this study.;
      %let exiterror=1;
      %goto exit;
   %end;
	
   *** Prepare ADSL ***;
   %PREPADSL;
   %if &exiterror %then %goto exit;
   
   %let Output_HTML = No;
   
   /* Simple strings and skeleton (fillable) strings */
   %let trAdvEvCtBySevLev =         %nrbquote(%LocaleGet(AdverseEventCountbySeverityLevel_Text));
   %let trAEEvOccAndPropRepforX =      %nrbquote(%LocaleGet(AEEventOccAndProportionReportforX_Text));
   %let trAEXPropReport =           %nrbquote(%LocaleGet(AEXproportionreport_Text));
   %let trAllEventTypes =           %nrbquote(%LocaleGet(AllEventTypes_Text));
   %let trAllSubjects =             %nrbquote(%LocaleGet(AllSubjects_Text));
   %let trBodySystemCount =         %nrbquote(%LocaleGet(BodySystemCount_Text));
   %let trCount =                   %nrbquote(%LocaleGet(Count_Text));
   %let trEventLC =        %nrbquote(%LocaleGet(event_Text));
   %let trMedicationCategoryCount =    %nrbquote(%LocaleGet(MedicationCategoryCount_Text));
   %let trPercent =              %nrbquote(%LocaleGet(Percent_Text));
   %let trPercentOccurrence =          %nrbquote(%LocaleGet(PercentOccurrence_Text));
   %let trPercentOccurrenceofX =       %nrbquote(%LocaleGet(PercentOccurrenceofX_Text));
   %let trPreTreatmentEvents =      %nrbquote(%LocaleGet(PreTreatmentEvents_Text));
   %let trOfftreatmentEvents =      %nrbquote(%LocaleGet(Offtreatmentfollowupevents_Text));
   %let trOntreatmentEvents =       %nrbquote(%LocaleGet(Ontreatmentevents_Text));
   %let trRace =                 %nrbquote(%LocaleGet(Race_Text));
   %let trReportingAllEvents =      %nrbquote(%LocaleGet(ReportingAllEvents_Text));
   %let trReportingEvWithALOvXOcc =    %nrbquote(%LocaleGet(ReportingEventswithatleastOverallXOcc_Text));
   %let trSex =                  %nrbquote(%LocaleGet(Sex_Text));
   %let trSSSUnclassifiedSSS =      %nrbquote(%LocaleGet(SSSUnclassifiedSSS_Text));
   %let trTotal =                   %nrbquote(%LocaleGet(Total_Text));
   %let trTotalCount =           %nrbquote(%LocaleGet(TotalCount_Text));
   %let trTotalCountofX =           %nrbquote(%LocaleGet(TotalCountofX_Text));
   %let trTreatment =               %nrbquote(%LocaleGet(Treatment_Text));
   %let trTreatmentEmergentAdvEvents = %nrbquote(%LocaleGet(TreatmentEmergentAdverseEvents_Text));
   %let trXforXChosen =             %nrbquote(%LocaleGet(XforXChosen_Text));
   %let trXIncSerAEOnlyforXChosen =    %nrbquote(%LocaleGet(XIncludingSeriousAdverseEventsOnlyforXChosen_Text));
   
   /* Filled strings (only those that are possible to fill ahead of time) */
   %let trAEEvOccAndPropRepforRace =   %nrbquote(%LocaleFill(&trAEEvOccAndPropRepforX, &trRace));
   %let trAEEvOccAndPropRepforSex =    %nrbquote(%LocaleFill(&trAEEvOccAndPropRepforX, &trSex));
   %let trAEEvOccAndPropRepforTrt =    %nrbquote(%LocaleFill(&trAEEvOccAndPropRepforX, &trTreatment));
   %let trAERacePropReport =        %nrbquote(%LocaleFill(&trAEXPropReport, &trRace));
   %let trAESexPropReport =         %nrbquote(%LocaleFill(&trAEXPropReport, &trSex));
   %let trAETrtPropReport =         %nrbquote(%LocaleFill(&trAEXPropReport, &trTreatment));
   %let trPercentOccurrenceofRace =    %nrbquote(%LocaleFill(&trPercentOccurrenceofX, &trRace));
   %let trPercentOccurrenceofSex =  %nrbquote(%LocaleFill(&trPercentOccurrenceofX, &trSex));
   %let trTotalCountofRace =        %nrbquote(%LocaleFill(&trTotalCountofX, &trRace));
   %let trTotalCountofSex =         %nrbquote(%LocaleFill(&trTotalCountofX, &trSex));
   
   %include "&MacroPath./DomainDistribution.sas";
   %AESerOnlyToAEWhereStmt;
   %LOADDATA(domlist=AE,mergesupp=&MergeSuppDom,checkreview=1,_TempWhereStmt =&AEWhereStmt);
 
   %include "&MacroPath./TEAEOTFU.sas";
   %if &exiterror %then %goto exit;   
   
   %let aesev =;
   %let aesevValue = ;
   %let TOXGRflg = %sysfunc(indexw(&AEVARS, AETOXGR, ' '));
   %if &TOXGRflg %then %do;
   	%let aesev =TOXGR;
   	%let aesevValue = AETOXGR;
   %end;
   %else %do;
   	%let aesevflg = %sysfunc(indexw(&AEVARS, AESEV, ' '));
   	%if &aesevflg %then %do;
   		%let aesev =SEV;
   		%let aesevValue = AESEV;
   	%end;
   %end;
 
   %let aerel =;
   %if %sysfunc(findw(&AEVARS, AEREL)) >0 %then %do;
   	%let aerel =REL;  
   %end;
   
   %if %sysfunc(findw(&AEVARS, AEDECOD)) > 0 %then %do;
      %let TmName = DECOD;
   %end;
   %else %if %sysfunc(findw(&AEVARS, AETERM)) > 0 %then %do;
      %let TmName = TERM;
   %end; 
   %else %do;
      %put [MS_S_0012];
      %put ERROR:  Neither the AEDECOD nor the AETERM variables were found in the AE data set.  At least one of these variables is required for this process.; 
      %let exiterror=1;
      %goto exit;
   %end;

   %let AEser = ;
   %let AEout = ;
   %if %sysfunc(findw(&AEVARS, AESER)) > 0 %then %do;
      %let AEser = SER;
   %end;

   %if %sysfunc(findw(&AEVARS, AEOUT)) > 0 %then %do;
      %let AEout = OUT;
   %end;

   %if %UPcase(&TrtUse) = NONE %then %do;
      proc freq data=&in_adsl noprint;
         tables &TrtName / out=fc;
         where not missing(&TrtName);
      run;
      
      %NObsVars(fc);
      %if &nobs < 2 %then %do;
         %let TrtLabel = ;
      %end;
      %let TrtName = ;
   %end;
   %let sexflag = %sysfunc(indexw(&ADSLVARS, SEX, ' '));
   %let raceflag = %sysfunc(indexw(&ADSLVARS, RACE, ' '));

	* prepare for word/pdf file;
   %if ^%length(&OutName) %then %do;
      %let OutName = AdverseEventsReport;
   %end;
   %let FullOutName = ;
   %PrepOutFile(FullOutName,OutName2,&OutName);
   %let OutName = &OutName2;
   %let OutData = OutLib.AEReport_&_nThePro_;

   proc sort data=&in_ae out=ae;
      by USUBJID;
   run;
   %Nobsvars(ae);
   %if &nobs=0 %then %do;
      %put [MS_S_0014];
      %put ERROR: There are no observations after filtering by the AE Filter.  Check that you have entered a valid filter.;
      %let exiterror=1;
      %goto exit;
   %end;
   %let fpos1_ = %sysfunc(indexw(&AEVARS, AE&TmName, ' '));
   %let fpos2_ = %sysfunc(indexw(&AEVARS, AEBODSYS, ' '));
         
   data ae; 
      set ae;
      %if &fpos1_ > 0 %then %do;
         if AE&TmName = "" then AE&TmName = "&trSSSUnclassifiedSSS";
      %end;
		%else %if &fpos1_ = 0 %then %do;
			length AE&TmName $ 18;
			AE&TmName = "&trSSSUnclassifiedSSS";
		%end;
      %if &fpos2_ > 0 %then %do;
         if AEBODSYS = "" then AEBODSYS = "&trSSSUnclassifiedSSS";
      %end;
		%else %if &fpos2_ = 0 %then %do;
			length AEBODSYS $ 18;
			AEBODSYS = "&trSSSUnclassifiedSSS";
		%end;
   run;
   
   %let percentvar = AE&TmName;
   %let T_trtNameP_flag =0;

   /* To get any ADSL filters - where stmt or population */
   proc sort data=&in_adsl out=adsl;
      by USUBJID;
   run;
   
   %nobsvars(adsl);
   %let nsubjects = &nobs;

   data &OutData;
      merge adsl(in=dmf) ae(drop=rfstdtc) ;
      by USUBJID;
      if missing(AE&TmName) then delete;
      if missing(AESTDY) or missing(AEDUR) then do;
         %calculateStudyDays(ae);
      end;
      if dmf;
   run;
   
   proc sort data=&OutData;
         by AE&TmName USUBJID 
            %if %length(&aeser) %then %do; descending AESER %end; %if %length(&aesev) %then %do; descending AE&aesev %end; AESTDY;
   run;
      
   data &OutData(keep=USUBJID STUDYID AE&TmName &TRTName %if &sexflag %then SEX; %if &raceflag %then RACE; %if &fpos2_ > 0 %then AEBODSYS; AEDECOD 
   			AETERM AE&AEser AE&aesev AESTDY);
      set &OutData;
      by AE&TmName USUBJID;
      if first.USUBJID then output;
   run;
   * copy the file for severity count;
   data outdataSer;
      set &in_ae;
   run;
   /* create counts for ordering */
   %let createcountvars = &TmName;
	%if &fpos2_ >0 %then %do;
		%let createcountvars = &TmName BODSYS;
	%end;
      
   %let i = 1;
   %do %while(%length(%scan(&createcountvars,&i)));
      %let tmvar = %scan(&createcountvars,&i);
      %let percentvar = AE&tmvar;
      %put percentvar=&percentvar OutData=&OutData;

      proc sort data=&OutData(keep=&percentvar) out=getcounts;
         by &percentvar;
      run;

      proc freq data=getcounts noprint;
         tables &percentvar / out=countdt;
      run;

      %if &i=1  %then %do;
         data countdt; set countdt;
            Percent = round((count/&nsubjects)*100,0.1);
            label Percent = "&trPercentOccurrence";
         run;
      %end;
         
      proc datasets;
         modify countdt;
         %if &i = 1 %then %do;
            label count = "&trTotalCount";
         %end;
         %else %do;
				rename count = group_count;
				label group_count = "&trBodySystemCount";
         %end;
      quit;

      proc sql;
         create table &OutData as
         select * from &OutData as d1 left join countdt as d2 on d1.&percentvar=d2.&percentvar
         order by USUBJID ;
      quit;
      %let i = %eval(&i+1);
   %end; 
   
   * include events with overall percent occurrence greater than the defined value;
   data &OutData;
   	set &OutData;
   	if PERCENT< &PropThresh then delete; 
   run;
	/* error checking after specifying minimum percentage */
	%NObsVars(&OutData);
	%if ^&nobs %then %do;
         %put [MS_S_0016];
         %put ERROR: There are no events that occur for at least &PropThresh percent of selected subjects.;
         %put ERROR: Please relax the Percent Occurrence Threshold on the dialog Output tab.;
         %let exiterror=1;
         %goto exit;
	%end;
	
   * Lili - create counts and calculate proportion for trt, sex and race;  
   %let AEserPercentVar = AE&aeser;
   %let AEDDtermVar =AE&TmName;
   %let AEtrtVar = &TrtVar;
   %let AErelVar =AE&aerel;
   %let AEoutVar=AE&aeout;
      
   * try to get sas name for TrtLabel;
   %if %length(&trtLabel) and %upcase(&TrtUse) ne NONE %then %do;    

      %*put AEserPercentVar=&AEserPercentVar AEDDtermVar=&AEDDtermVar AEtrtVar=&TrtVar &TrtUse &trtLabel trtNameP=&trtNameP;
      *get the total count for each trt;
      proc sort data=&in_adsl out=trtNameSum;
         by &trtName;
      run;
      proc freq data=trtNameSum noprint;
         tables &trtName /out=trtsum1;
      run;
      %SortRowsByValueOrdering(trtsum1, &trtName);

		* get total count for treatment levels from adsl data;
      %let _tid_=%sysfunc(open(trtsum1));
      %let nv_trt = %sysfunc(attrn(&_tid_,NOBS)); 
      %let trtTotal=0;
      %do _i_ = 1 %to &nv_trt;
         %let _rc_=%sysfunc(fetchobs(&_tid_,&_i_));
         %let trtNameV&_i_ = %sysfunc(getvarc(&_tid_,%sysfunc(varnum(&_tid_,&trtName))));
         %let trtNameT&_i_ = %sysfunc(getvarn(&_tid_,%sysfunc(varnum(&_tid_,COUNT))));
         %let trtTotal = %eval(&trtTotal+&&trtNameT&_i_);
         %*put trtNameV=&&trtNameV&_i_ trtNameT&_i_=&&trtNameT&_i_ trtTotal=&trtTotal;
      %end;
      %let _tid_ = %sysfunc(close(&_tid_));
      
      *calculate proportion for trt: DECOD/TERM depending on which one is picked;
      proc sort data=&OutData(keep=&trtName &AEDDtermVar usubjid) out=getcounts1;
         by &AEDDtermVar &trtName usubjid;
      run;  
      proc freq data=getcounts1 noprint;
         tables &AEDDtermVar*&trtName / out=countdt1;
      run;
    
      %let trPercentOccofTrtLabel = %nrbquote(%LocaleFill(&trPercentOccurrenceofX, f1=%nrbquote(&trtLabel)));
      
      data countdt1; 
         set countdt1;
         %do _i_ = 1 %to &nv_trt;
            if &trtName="&&trtNameV&_i_" then do;
               Percent_trt = round((count/&&trtNameT&_i_)*100,0.1);
               label Percent_trt = "&trPercentOccofTrtLabel";
            end;
         %end;
      run;
   
      proc datasets;
         modify countdt1;
				%let trTotalCountofTrtLabel = %nrbquote(%LocaleFill(&trTotalCountofX, f1=%nrbquote(&trtLabel)));
				rename count = group_count1;
				label group_count1 = "&trTotalCountofTrtLabel";
      quit; 

      *merge Trt count and proportion with output table;    
      proc sql;
         create table &OutData as
         select * from &OutData as d1 left join countdt1 as d2 on d1.&AEDDtermVar=d2.&AEDDtermVar and d1.&trtName=d2.&trtName
         order by USUBJID ;
      quit;
      data countdt1;
         set countdt1;
         retain T_trtNameP 0;
         if Percent_trt ^= . then T_trtNameP=T_trtNameP+1;
      run;
      data _null_;
         set countdt1;
         call symput("T_trtNameP_flag",trim(left(T_trtNameP)));
      run;
      %put T_trtNameP_flag=&T_trtNameP_flag ;
      
      *calculate proportion by AEBODSYS ;
		proc sort data=&OutData(keep=&trtName USUBJID &AEDDtermVar AEBODSYS) out = getcounts2;
         by AEBODSYS &trtName USUBJID &AEDDtermVar;
      run;
      
      data getcounts2;
       set getcounts2;
       by AEBODSYS &trtName USUBJID &AEDDtermVar;
       if first.usubjid;
      run;
      
       proc freq data=getcounts2 noprint;
			tables &trtName /out=countdt6;
			by AEBODSYS &trtName;
		run;
		%let trPercentOccofBDLabel = %nrbquote(%LocaleGet(PercentOccurrenceofBODYSYS_Text));;
      data countdt6; 
         set countdt6;
         %do _i_ = 1 %to &nv_trt;
            if &trtName="&&trtNameV&_i_" then do;
               Percent_BStrt = round((count/&&trtNameT&_i_)*100,0.1);
               label Percent_BStrt = "&trPercentOccofBDLabel";
            end;
         %end;
      run;
   
      proc datasets;
         modify countdt6;
				%let trTotalCountofBSLabel = %nrbquote(%LocaleGet(&trTotalCountoBodySys));
				rename count = BodySys_count1;
				label BodySys_count1 = "&trTotalCountofBSLabel";
      quit; 

      *merge Trt count and proportion with output table;
      proc sql;
         create table &OutData as
         select * from &OutData as d1 left join countdt6 as d2 on d1.AEBODSYS=d2.AEBODSYS and d1.&trtName=d2.&trtName
         order by USUBJID ;
      quit;    
      
   %end;
   %if &sexflag %then %do;
      *get the total count for each Sex;
      proc sort data=&in_adsl out=SexNameSum;
         by Sex;
      run;
      proc freq data=SexNameSum noprint;
         tables Sex /out=Sexsum;
      run;
        data Sexsum;
 	    set Sexsum;
 	    if missing(Sex) then delete;
	run;
      %SortRowsByValueOrdering(Sexsum, Sex);
      
      * get total count for sex levels from adsl data;
      %let _tid_=%sysfunc(open(Sexsum));
      %let nv_sex = %sysfunc(attrn(&_tid_,NOBS)); 
      %let SexTotal=0;
      %do _i_ = 1 %to &nv_sex;
         %let _rc_=%sysfunc(fetchobs(&_tid_,&_i_));
         %let varnumber = %sysfunc(varnum(&_tid_,Sex));
         %let vartype = %sysfunc(vartype(&_tid_,&varnumber));
         %if &vartype = C %then %let sexNameV&_i_ = %sysfunc(getvarc(&_tid_,%sysfunc(varnum(&_tid_,Sex))));
         %else %let sexNameV&_i_ = %sysfunc(getvarn(&_tid_,%sysfunc(varnum(&_tid_,Sex))));
         %let sexNameT&_i_ = %sysfunc(getvarn(&_tid_,%sysfunc(varnum(&_tid_,COUNT))));
         %let SexTotal=%eval(&SexTotal+&&sexNameT&_i_);
         %*put sexNameV=&&sexNameV&_i_ sexNameT&_i_=&&sexNameT&_i_ SexTotal=&SexTotal;
      %end;
      %let _tid_ = %sysfunc(close(&_tid_));
   
      *calculate proportion for Sex DECOD/TERM depending on which one is picked;
      proc sort data=&OutData(keep=Sex &AEDDtermVar usubjid) out=getcounts1;
         by &AEDDtermVar Sex usubjid;
      run;  
      proc freq data=getcounts1 noprint;
         tables &AEDDtermVar*Sex / out=countdt1;
      run;

      data countdt1; 
         set countdt1;
         %do _i_ = 1 %to &nv_sex;
            if Sex="&&sexNameV&_i_" then do;
               Percent_Sex = round((count/&&sexNameT&_i_)*100,0.1);
               label Percent_Sex = "&trPercentOccurrenceofSex";
            end;
         %end;
      run;
   
      proc datasets;
         modify countdt1;
				rename count = group_count2;
				label group_count2 = "&trTotalCountofSex";
      quit; 

      *merge Sex count and proportion with output table;
      proc sql;
         create table &OutData as
         select * from &OutData as d1 left join countdt1 as d2 on d1.&AEDDtermVar=d2.&AEDDtermVar and d1.Sex=d2.Sex
         order by USUBJID ;
      quit;
      *calculate proportion by AEBODSYS ;
		proc sort data=&OutData(keep=Sex &AEDDtermVar AEBODSYS USUBJID) out = getcounts2;
         by AEBODSYS Sex USUBJID &AEDDtermVar;
      run;
      
      data getcounts2;
         set getcounts2;
         by AEBODSYS Sex USUBJID &AEDDtermVar;
         if first.usubjid;
      run;
      
       proc freq data=getcounts2 noprint;
			tables Sex /out=countdt6;
			by AEBODSYS Sex;
		run;
		%let trPercentOccofBDSex = %nrbquote(%LocaleGet(PercentOccurrenceofBODYSYSSex_Text));;
      data countdt6; 
         set countdt6;
         %do _i_ = 1 %to &nv_sex;
            if Sex="%nrbquote(&&sexNameV&_i_)" then do;
               Percent_BSSex = round((count/&&sexNameT&_i_)*100,0.1);
               label Percent_BSSex = "&trPercentOccofBDSex";
            end;
         %end;
      run;
   
      proc datasets;
         modify countdt6;
				%let trTotalCountofBSSex = %nrbquote(%LocaleGet(&trTotalCountoBSSex));
				rename count = BodySys_count2;
				label BodySys_count2 = "&trTotalCountofBSRace";
      quit; 

      *merge Trt count and proportion with output table;
      proc sql;
         create table &OutData as
         select * from &OutData as d1 left join countdt6 as d2 on d1.AEBODSYS=d2.AEBODSYS and d1.Sex=d2.Sex
         order by USUBJID ;
      quit; 
   %end;
   
   %if &raceflag %then %do;
      *get the total count for each Race;
      proc sort data=&in_adsl out=RaceNameSum;
         by Race;
      run;
      * check RACE is character or numeric variable;      
      proc freq data=RaceNameSum noprint;
         tables Race /out=racesum;
      run;
      %SortRowsByValueOrdering(racesum, Race);
      
      * get total count for Race levels from adsl data;
      %let _tid_=%sysfunc(open(racesum));
      %let nv_race = %sysfunc(attrn(&_tid_,NOBS)); 
      %let raceTotal=0;
      %do _i_ = 1 %to &nv_race;
         %let _rc_=%sysfunc(fetchobs(&_tid_,&_i_));
         %let varnumber = %sysfunc(varnum(&_tid_,Race));
         %let vartype = %sysfunc(vartype(&_tid_,&varnumber));
         %if &vartype = C %then %let raceNameV&_i_ = %sysfunc(getvarc(&_tid_,%sysfunc(varnum(&_tid_,Race))));
         %else %let raceNameV&_i_ = %sysfunc(getvarn(&_tid_,%sysfunc(varnum(&_tid_,Race))));
         %let raceNameT&_i_ = %sysfunc(getvarn(&_tid_,%sysfunc(varnum(&_tid_,COUNT))));
         %let raceTotal=%eval(&raceTotal+&&raceNameT&_i_);
         %put raceNameV=&&raceNameV&_i_ raceNameT&_i_=&&raceNameT&_i_ raceTotal=&raceTotal;
      %end;
      %let _tid_ = %sysfunc(close(&_tid_));
      %let nv_raceTmp=&nv_race;

      *calculate proportion for Race DECOD/TERM depending on which one is picked;
      proc sort data=&OutData(keep=Race &AEDDtermVar usubjid) out=getcounts1;
         by &AEDDtermVar Race usubjid;
      run;  
      proc freq data=getcounts1 noprint;
         tables &AEDDtermVar*Race / out=countdt1;
      run;

      data countdt1; 
         set countdt1;
         %do _i_ = 1 %to &nv_race;
            if Race="%nrbquote(&&raceNameV&_i_)" then do;
               Percent_race = round((count/&&raceNameT&_i_)*100,0.1);
               label Percent_race = "&trPercentOccurrenceofRace";
            end;
         %end;
      run;
   
      proc datasets;
         modify countdt1;
				rename count = group_count3;
				label group_count3 = "&trTotalCountofRace";
      quit; 

      *merge Race count and proportion with output table;
      proc sql;
         create table &OutData as
         select * from &OutData as d1 left join countdt1 as d2 on d1.&AEDDtermVar=d2.&AEDDtermVar and d1.Race=d2.Race
         order by USUBJID ;
      quit;
      
      *calculate proportion by AEBODSYS ;
		proc sort data=&OutData(keep=Race &AEDDtermVar AEBODSYS USUBJID) out = getcounts2;
         by AEBODSYS Race USUBJID &AEDDtermVar;
      run;
      
      data getcounts2;
         set getcounts2;
         by AEBODSYS Race USUBJID &AEDDtermVar;
         if first.usubjid;
      run;
      
       proc freq data=getcounts2 noprint;
			tables Race /out=countdt6;
			by AEBODSYS Race;
		run;
		%let trPercentOccofBDRace = %nrbquote(%LocaleGet(PercentOccurrenceofBODYSYSRACE_Text));;
      data countdt6; 
         set countdt6;
         %do _i_ = 1 %to &nv_race;
            if Race="%nrbquote(&&raceNameV&_i_)" then do;
               Percent_BSrace = round((count/&&raceNameT&_i_)*100,0.1);
               label Percent_BSrace = "&trPercentOccofBDRace";
            end;
         %end;
      run;
   
      proc datasets;
         modify countdt6;
				%let trTotalCountofBSRace = %nrbquote(%LocaleGet(&trTotalCountoBSRACE));
				rename count = BodySys_count3;
				label BodySys_count3 = "&trTotalCountofBSRace";
      quit; 

      *merge Trt count and proportion with output table;
      proc sql;
         create table &OutData as
         select * from &OutData as d1 left join countdt6 as d2 on d1.AEBODSYS=d2.AEBODSYS and d1.Race=d2.Race
         order by USUBJID ;
      quit;    
      
   %end;

   * use proc report to get the summary report for proportion and count for trt;
   %if %length(&trtLabel) and %upcase(&TrtUse) ne NONE %then %do;
      data stattable_sub;
         set &OutData;
         keep USUBJID &AEDDtermVar AEBODSYS &trtName Sex Race COUNT PERCENT group_count group_count1 Percent_trt /*group_count2 Percent_Sex group_count3*/ 
          BodySys_count1 Percent_BStrt /*BodySys_count2 Percent_BSSex BodySys_count3 Percent_BSrace Percent_race*/;
      run;

      proc sort data=stattable_sub out=stattable_sub nodupkey;
         by &AEDDtermVar &trtName;
      run;
      %slicedata(stattable_sub,&trtName,trtLvlData,%sysfunc(pathname(work)),_SubDataList=sList);
      %NObsVars(trtLvlData);
      %let nsub = &nObs;
      %if &nsub <  &nv_trt %then %do;
      	%let nv_trt=&nsub;
      	proc sort data =trtsum1;
      	by &trtName;
      	run;
      	proc sort data = trtLvlData;
      	by &trtName;
      	run;
      	data trtsum1;
      		merge trtsum1(in=a) trtLvlData(in=b);
      		by &trtName;
      		if b;
      	run;
      	%SortRowsByValueOrdering(trtsum1, &trtName);
      	%let _tid_=%sysfunc(open(trtsum1));
      	%do _i_ = 1 %to &nv_trt;
      	   %let _rc_=%sysfunc(fetchobs(&_tid_,&_i_));
      	   %let trtNameV&_i_ = %sysfunc(getvarc(&_tid_,%sysfunc(varnum(&_tid_,&trtName))));
      	   %let trtNameT&_i_ = %sysfunc(getvarn(&_tid_,%sysfunc(varnum(&_tid_,COUNT))));
      	   %*put i=&_i_ trtNameV=&&trtNameV&_i_ trtNameT&_i_=&&trtNameT&_i_ trtTotal=&trtTotal;
      	%end;
      	%let _tid_ = %sysfunc(close(&_tid_));
      	
      %end;
		%let nsubjects=&trtTotal;

      proc sort data=&OutData out = trt_BST nodupkey;
         by AEBODSYS &trtName;
      run;
      %slicedata(trt_BST,&trtName,trtBslData,%sysfunc(pathname(work)),_SubDataList=sList);
      data trtBslData;
         set trtBslData;
         if &trtName="" then delete;
      run;
      %NObsVars(trtBslData);
      %let bsobs=&nObs;
      %do _i_ = 1 %to &bsobs;
         %let _tid_=%sysfunc(open(trt_BST&_i_));
         %let nv_bs2&_i_ = %sysfunc(attrn(&_tid_,NOBS));
         %do _j_ = 1 %to &&nv_bs2&_i_;
            %let _rc_=%sysfunc(fetchobs(&_tid_,&_j_));
            %let BodySysLvlV&_i_._&_j_ = %sysfunc(getvarc(&_tid_,%sysfunc(varnum(&_tid_,AEBODSYS))));
            %let BodySysCount&_i_._&_j_ = %sysfunc(getvarn(&_tid_,%sysfunc(varnum(&_tid_,BodySys_count1))));
            %let BodySysPercent&_i_._&_j_ = %sysfunc(getvarn(&_tid_,%sysfunc(varnum(&_tid_,Percent_BStrt))));
            %let BodySysTrt&_i_._&_j_ = %sysfunc(getvarc(&_tid_,%sysfunc(varnum(&_tid_,&trtName))));
            %put BodySysLvlV&_i_._&_j_=&&BodySysLvlV&_i_._&_j_ BodySysCount&_i_._&_j_=&&BodySysCount&_i_._&_j_ BodySysTrt&_i_._&_j_=&&BodySysTrt&_i_._&_j_;
         %end;
         %let _tid_ = %sysfunc(close(&_tid_));
      %end;
        
      * merge count and percent by AEDECOD/AETerm level for treatment;  
      %do _i_ = 1 %to &nv_trt;
         %let trtNameLabel&_i_=&&trtNameV&_i_;
         %let trtNameV&_i_=%sysfunc(translate(&&trtNameV&_i_,'_','.','_',' ','_','/','_','(','_',')','_',',','_','-','_',":"));
         %if %length(&&trtNameV&_i_) <29 %then %let trtNameShort&_i_=&&trtNameV&_i_; 
         %else %let trtNameShort&_i_=%substr(&&trtNameV&_i_,1,28);
         data stattable_sub&_i_;
            length Gt1_trtName&_i_ $16 Pt1_trtName&_i_ $8 count_trt $16 PERCENT_Ttrt $8;
            set stattable_sub&_i_;
            /*rename COUNT=COUNT_&&trtNameV&_i_ PERCENT=PERCENT_&&trtNameV&_i_ group_count=group_count_&&trtNameV&_i_ group_count1=group_count1_&&trtNameV&_i_ Percent_trt=Percent_trt_&&trtNameV&_i_ 
               group_count2=group_count2_&&trtNameV&_i_ Percent_Sex=Percent_Sex_&&trtNameV&_i_;*/
               Gt1_trtName&_i_=group_count1;
					Pt1_trtName&_i_=Percent_trt;
               Gt1_trtName&_i_=trim(left(Gt1_trtName&_i_))||" ("||trim(left(Pt1_trtName&_i_))||")";
               count_trt=COUNT;  
               PERCENT_Ttrt=PERCENT;
               count_trt =trim(left(count_trt))||" ("||trim(left(PERCENT_Ttrt))||")";
               label Gt1_trtName&_i_ =&&trtNameLabel&_i_;
               rename group_count1=group_count1&_i_ Percent_trt=Percent_trt&_i_;
               *drop group_count1 Percent_trt COUNT PERCENT;
         run;
         proc sort data= stattable_sub&_i_;
            by &AEDDtermVar;
         run;

         %if &_i_=1 %then %do;
            data stattable_subt;
               set stattable_sub&_i_;
            run;
         %end;
         %else %do;
            data stattable_subt;
               merge stattable_subt(in=a) stattable_sub&_i_(in=b);
               by &AEDDtermVar;
               if a or b;
            run;
         %end;
      %end;
      
      data stattable_subt;
         retain count_trtTA 0;
         set stattable_subt;
         %do _i_ = 1 %to &nv_trt;
            %if &_i_ =1 %then %do;
               if group_count1&_i_ =. then count_trtTA=0;
               else count_trtTA=group_count1&_i_;
            %end;
            %else %do;
               if group_count1&_i_ =. then count_trtTA=count_trtTA+0;
               else count_trtTA=count_trtTA+group_count1&_i_;
            %end;
         %end;
      run;

      data stattable_subt;
         length percent_trtA $8 count_trtA $16;
         set stattable_subt;
         count_trtA =count_trtTA;
         percent_trtTA = round((count_trtTA/&nsubjects)*100,0.1);
         percent_trtA=percent_trtTA;
         count_trtA =trim(left(count_trtA))||" ("||trim(left(percent_trtA))||")";
         if percent_trtTA< &PropThresh then delete;
         drop percent_trtTA count_trtTA count_trt;
         rename count_trtA=count_trt;
      run;

      * get indent for AE events;
      data stattable_subt;
         set stattable_subt;
         AEDDtermVar_pdf= %str("00"x)|| " " || &AEDDtermVar;
         AEDDtermVar_text= %str('1E'x)|| " " || %str('1E'x)|| " " || %str('1E'x)|| &AEDDtermVar;
         AEDDtermVar_rtf =%str('03'x) || " " ||%str('03'x) || " " || &AEDDtermVar ;
      run;
         
      proc sort data =stattable_subt;
         by AEBODSYS &trtName;
      run;

		* Get body stystem class levels and insert it before AEDECOD/AETERM starts;
      %slicedata(stattable_subt,AEBODSYS,bsLvlData,%sysfunc(pathname(work)),_SubDataList=sList);
      %NObsVars(bsLvlData);
      %let nv_bodysystem = &nObs;
            
      *get the body system level;      
      %do _i_ = 1 %to &nv_bodysystem;     	
         %let _tid_=%sysfunc(open(stattable_subt&_i_));
         %let nv_trt2 = %sysfunc(attrn(&_tid_,NOBS));
         %do _j_ = 1 %to &nv_trt2;
            %let _rc_=%sysfunc(fetchobs(&_tid_,&_j_));
            %let BodySysNameV = %sysfunc(getvarc(&_tid_,%sysfunc(varnum(&_tid_,AEBODSYS))));
            %let trtSysNameV = %sysfunc(getvarc(&_tid_,%sysfunc(varnum(&_tid_,&trtName))));
         %end;
         %let _tid_ = %sysfunc(close(&_tid_));
               
         %let bsSum=0;
         %*let bsUIDSum=0;
         %do _m_ = 1 %to &bsobs;
            %let bsTotal&_m_=;
            %do _n_ = 1 %to &&nv_bs2&_m_;
               %*put BodySysNameV=&BodySysNameV trtSysNameV=&trtSysNameV;
               %*put BodySysLvlV&_m_._&_n_=&&BodySysLvlV&_m_._&_n_ BodySysCount&_m_._&_n_=&&BodySysCount&_m_._&_n_ BodySysTrt&_m_._&_n_=&&BodySysTrt&_m_._&_n_;
               %if %qupcase(&&BodySysLvlV&_m_._&_n_) =%qupcase(&BodySysNameV) %then %do;
                  %*put m=&_m_ n=&_n_ BodySysCount&_m_._&_n_=&&BodySysCount&_m_._&_n_;
                  %let bsTotal&_m_=&&BodySysCount&_m_._&_n_; 
                  %let bsUID&_m_ =&&BodySysPercent&_m_._&_n_; 
                  %*let bsUID&_m_ =%sysfunc(round(%sysevalf(&&BodySysCount&_m_._&_n_/&&trtNameT&_m_)*100,0.1));
                  %let bsSum=%eval(&bsSum+&&BodySysCount&_m_._&_n_);
                  %let bsTRTLvL&_m_ = &&BodySysTrt&_m_._&_n_;
                  %let _n_= &&nv_bs2&_m_;
               %end;
               %*put bsTotal&_m_=&&bsTotal&_m_;
            %end;
         %end;
            
         %let bsUIDPerc=%sysfunc(round(%sysevalf(&bsSum/&trtTotal)*100,0.1));
               
         data stattable_subtbs;
            set stattable_subt&_i_;
            if _n_=1 then do;
               &AEDDtermVar = "&BodySysNameV";
               AEDDtermVar_pdf="&BodySysNameV";
               AEDDtermVar_text="&BodySysNameV";
               AEDDtermVar_rtf="&BodySysNameV";
               AEBODSYS=" ";
               &trtName=" ";
               Sex =" ";
               Race = " ";
               count_trt ="&bsSum(&bsUIDPerc)";
               PERCENT_Ttrt =" ";
               group_count =" ";
               group_count2 =" ";
               Percent_Sex =" ";
               group_count3 =" ";
               Percent_race=" ";
               %do _j_ = 1 %to &nv_trt;
                  Gt1_trtName&_j_=" ";
                  %if %symexist(bsTotal&_j_) %then %do;
                     %if %length(&&bsTotal&_j_) %then %do;
                        Gt1_trtName&_j_= "&&bsTotal&_j_(&&bsUID&_j_)";
                     %end;
                  %end;
                  %else %do;
                     Gt1_trtName&_j_=.;
                  %end;
               /* if &&bsTotal&_j_ >0 then do;
                     Gt1_&&trtNameShort&_j_= "N=&&bsTotal&_j_";
                  end;
                  else do;
                     Gt1_&&trtNameShort&_j_= " ";
                  end;*/
                  Pt1_trtName&_j_= " ";
               %end;
            end;
            else delete;
         run;
         data stattable_subt&_i_;
            set stattable_subtbs stattable_subt&_i_;
         run;

         %if &_i_=1 %then %do;
            data stattable_subt;
               set stattable_subt&_i_;
            run;
         %end;
         %else %do;
            data stattable_subt;
               set stattable_subt stattable_subt&_i_;
            run;
         %end;
      %end;
               
      data stattable_subtT;
         set stattable_subt;
            if _n_=1 then do;
               &AEDDtermVar = "&trTotal";
               AEDDtermVar_pdf="&trTotal";
               AEDDtermVar_text="&trTotal";
               AEDDtermVar_rtf="&trTotal";
               AEBODSYS=" ";
               &trtName=" ";
               Sex =" ";
               Race = " ";
               count_trt ="N=&trtTotal";
               PERCENT_Ttrt =" ";
               group_count =" ";
               group_count2 =" ";
               Percent_Sex =" ";
               group_count3 =" ";
               Percent_race=" ";
               %do _i_ = 1 %to &nv_trt;
                  Gt1_trtName&_i_= "N=&&trtNameT&_i_";
                  Pt1_trtName&_i_= " ";
               %end;
            end;
            else delete;
      run;
      data stattable_subt;
         set stattable_subtT stattable_subt;
      run;
   %end;

   %if &sexflag %then %do;
     data &OutData;
       	set &OutData;
       	if missing(Sex) then delete;
      run;
   	data stattable_sub;
   	   set &OutData;
   	   keep USUBJID &AEDDtermVar AEBODSYS Sex Race COUNT PERCENT group_count group_count1 Percent_trt group_count2 Percent_Sex group_count3 
   	   BodySys_count1 BodySys_count2 BodySys_count3 Percent_BStrt Percent_BSSex Percent_BSrace Percent_race;
   	run;
         
   	proc sort data=stattable_sub  nodupkey;
   	   by &AEDDtermVar Sex ;
   	run;
   	%slicedata(stattable_sub,Sex,trtLvlData,%sysfunc(pathname(work)),_SubDataList=sList);
         
   	%NObsVars(trtLvlData);
   	%let nsub = &nObs;
   	%put nsub = &nsub nv_sex =&nv_sex;
   	%if &nsub <  &nv_sex %then %let nv_sex=&nsub;
         
      proc sort data=&OutData out = sex_BST nodupkey;
         by AEBODSYS SEX;
      run;   	
   	%slicedata(sex_BST,SEX,trtBslData,%sysfunc(pathname(work)),_SubDataList=sList);
   	
   	%NObsVars(trtBslData);
   	%let bsobs=&nObs;
   	%do _i_ = 1 %to &bsobs;
   	   %let _tid_=%sysfunc(open(sex_BST&_i_));
   	   %let nv_bs2&_i_ = %sysfunc(attrn(&_tid_,NOBS));
   	   %do _j_ = 1 %to &&nv_bs2&_i_ ;
   	      %let _rc_=%sysfunc(fetchobs(&_tid_,&_j_));
   	      %let BodySysLvlV&_i_.&_j_ = %sysfunc(getvarc(&_tid_,%sysfunc(varnum(&_tid_,AEBODSYS))));
   	      %let BodySysCount&_i_.&_j_ = %sysfunc(getvarn(&_tid_,%sysfunc(varnum(&_tid_,BodySys_count2))));
   	      %let BodySysPercent&_i_.&_j_ = %sysfunc(getvarn(&_tid_,%sysfunc(varnum(&_tid_,Percent_BSSex))));
   	      %let BodySysSex&_i_.&_j_ = %sysfunc(getvarc(&_tid_,%sysfunc(varnum(&_tid_,SEX))));
   	   %end;
   	   %let _tid_ = %sysfunc(close(&_tid_));
   	%end;

		* merge count and percent by AEDECOD/AETerm level for sex;
   	%do _i_ = 1 %to &nv_sex;
   	   %let sexNameLabel&_i_=&&sexNameV&_i_;
   	   %let sexNameV&_i_=%sysfunc(translate(&&sexNameV&_i_,'_','.','_',' ','_','/','_','(','_',')','_',',','_','-'));
   	   data stattable_sub&_i_;
   	      length Gt1_sexName&_i_ $16 Pt1_sexName&_i_ $8;
   	      set stattable_sub&_i_;
   	      Gt1_sexName&_i_ = group_count2;
   	      Pt1_sexName&_i_ = Percent_sex;
   	      Gt1_sexName&_i_=trim(left(Gt1_sexName&_i_))||" ("||trim(left(Pt1_sexName&_i_))||")";
   	      label Gt1_sexName&_i_ =&&sexNameLabel&_i_;
   	      rename group_count2=group_count2&_i_ Percent_sex=Percent_sex&_i_;
   	   run;
   	   proc sort data= stattable_sub&_i_;
   	      by &AEDDtermVar;
   	   run;
   	   %if &_i_=1 %then %do;
   	      data stattable_subS;
   	         set stattable_sub&_i_;
   	      run;
   	   %end;
   	   %else %do;
   	      data stattable_subS;
   	         merge stattable_subS(in=a) stattable_sub&_i_(in=b);
   	         by &AEDDtermVar;
   	         if a or b;
   	      run;
   	   %end;
   	%end;
   	data stattable_subS;
   	   retain count_SexTA 0;
   	   set stattable_subS;
   	   %do _i_ = 1 %to &nv_sex;
   	      %if &_i_ =1 %then %do;
   	         if group_count2&_i_ =. then count_SexTA=0;
   	         else count_SexTA=group_count2&_i_;
   	      %end;
   	      %else %do;
   	         if group_count2&_i_ =. then count_SexTA=count_SexTA+0;
   	         else count_SexTA=count_SexTA+group_count2&_i_;
   	      %end;
   	   %end;
   	run;
   	data stattable_subS;
   	   length percent_Sex $8 count_Sex $16;
   	   set stattable_subS;
   	   count_Sex =count_SexTA; 
   	   percent_SexTA = round((count_SexTA/&nsubjects)*100,0.1);
   	   percent_Sex=percent_SexTA;          
   	   /*%do _i_ = 1 %to &nv_sex;
   	      if Pt1_&&sexNameV&_i_ < &PropThresh then delete;
   	   %end;*/
   	   count_Sex =trim(left(count_Sex))||" ("||trim(left(percent_Sex))||")";
   	   if percent_SexTA < &PropThresh then delete;
   	   drop percent_SexTA count_SexTA;
   	run;
	
   	data stattable_subS;
   	   set stattable_subS;
   	   AEDDtermVar_pdf= %str("00"x)|| " " || &AEDDtermVar;
   	   AEDDtermVar_text= %str('1E'x)|| " " || %str('1E'x)|| " " || %str('1E'x)|| &AEDDtermVar;
   	   AEDDtermVar_rtf =%str('03'x) || " " ||%str('03'x) || " " || &AEDDtermVar ;          
   	run;
         
   	proc sort data =stattable_subS;
   	   by AEBODSYS SEX;
   	run;
   	            
   	%slicedata(stattable_subS,AEBODSYS,bsLvlData,%sysfunc(pathname(work)),_SubDataList=sList);
   	%NObsVars(bsLvlData);
   	%let nv_bodysystem = &nObs;
   	         
   	*get the body system level;      
   	%do _i_ = 1 %to &nv_bodysystem;
   	   %let _tid_=%sysfunc(open(stattable_subS&_i_));
   	   %let nv_trt2 = %sysfunc(attrn(&_tid_,NOBS)); 
   	   %do _j_ = 1 %to &nv_trt2;
   	      %let _rc_=%sysfunc(fetchobs(&_tid_,&_j_));
   	      %let BodySysNameV = %sysfunc(getvarc(&_tid_,%sysfunc(varnum(&_tid_,AEBODSYS))));
   	   %end;
   	   %let _tid_ = %sysfunc(close(&_tid_));
   	   
   	   %let bsSum=0;
   	   %do _m_ = 1 %to &bsobs;
   	      %let bsTotal&_m_=;
   	      %do _n_ = 1 %to &&nv_bs2&_m_ ;
   	         %if %qupcase(&&BodySysLvlV&_m_.&_n_) =%qupcase(&BodySysNameV) %then %do;
   	            %let bsTotal&_m_=&&BodySysCount&_m_.&_n_; 
   	            %let bsUID&_m_ = &&BodySysPercent&_m_.&_n_; 
   	            %let bsSum=%eval(&bsSum+&&BodySysCount&_m_.&_n_);
   	            %let bsSexLvL&_m_ = &&BodySysSex&_m_.&_n_;
   	            %let _n_= &&nv_bs2&_m_ ;
   	            %*put bsTotal&_m_=&&bsTotal&_m_ bsUID&_m_=&&bsUID&_m_ bsSum=&bsSum bsSexLvL&_m_=&&bsSexLvL&_m_;
   	         %end; 
   	      %end;
   	   %end;
   	         
   	   %let bsUIDPerc=%sysfunc(round(%sysevalf(&bsSum/&SexTotal)*100,0.1));
   	            
   	   data stattable_subSbs;
   	   *   length sex $40;
   	      set stattable_subS&_i_;
   	      if _n_=1 then do;
   	         &AEDDtermVar = "&BodySysNameV";
   	         AEDDtermVar_pdf="&BodySysNameV";
   	         AEDDtermVar_text="&BodySysNameV";
   	         AEDDtermVar_rtf="&BodySysNameV";
   	         AEBODSYS=" ";
					Race = " ";
   	         COUNT =" ";
   	         PERCENT =" ";
   	         group_count =" ";
   	         group_count1 =" ";
   	         Percent_trt =" ";
   	         group_count3 =" ";
   	         Percent_race=" ";
   	         call missing(Sex);
   	         %do _j_ = 1 %to &nv_sex;
   	            Gt1_sexName&_j_= " ";
   	            %if %length(&&bsTotal&_j_ ) %then %do;
   	               Gt1_sexName&_j_= "&&bsTotal&_j_(&&bsUID&_j_)";
   	            %end;
   	            Pt1_sexName&_j_= " ";
   	         %end;
   	         count_Sex = "&bsSum(&bsUIDPerc)";
   	         percent_Sex=" ";
   	      end;
   	      else delete;
   	   run;
   	   data stattable_subS&_i_;
   	      set stattable_subSbs stattable_subS&_i_;
   	   run;
	
   	   %if &_i_=1 %then %do;
   	      data stattable_subS;
   	         set stattable_subS&_i_;
   	      run;
   	   %end;
   	   %else %do;
   	      data stattable_subS;
   	         set stattable_subS stattable_subS&_i_;
   	      run;
   	   %end;
   	%end;
   	      
   	data stattable_subST;
   	   set stattable_subS;
   	      if _n_=1 then do;
   	         &AEDDtermVar = "&trTotal";
   	         AEDDtermVar_pdf="&trTotal";
   	         AEDDtermVar_text="&trTotal";
   	         AEDDtermVar_rtf="&trTotal";
   	         AEBODSYS=" ";
   	         Sex =" ";
   	         Race = " ";
   	         COUNT =" ";
   	         PERCENT =" ";
   	         group_count =" ";
   	         group_count1 =" ";
   	         Percent_trt =" ";
   	         group_count3 =" ";
   	         Percent_race=" ";
   	         %do _i_ = 1 %to &nv_sex;
   	            Gt1_sexName&_i_= "N=&&sexNameT&_i_";
   	            Pt1_sexName&_i_= " ";
   	         %end;
   	         count_Sex = "N=&SexTotal";
   	         percent_Sex=" ";
   	      end;
   	      else delete;
   	run;
   	data stattable_subS;
   	   set stattable_subST stattable_subS;
   	run;
   	%end;
   	
   %if &raceflag %then %do; 
       data &OutData;
       	set &OutData;
       	if missing(Race) then delete;
      run;
   	data stattable_sub;
   	   set &OutData;
  		    keep USUBJID &AEDDtermVar AEBODSYS Sex Race COUNT PERCENT group_count group_count1 Percent_trt group_count2 Percent_Sex group_count3 
  		    BodySys_count1 BodySys_count2 BodySys_count3 Percent_BStrt Percent_BSSex Percent_BSrace Percent_race;
   	run;

		proc sort data=stattable_sub  out =stattable_sub nodupkey;
			by &AEDDtermVar Race ;
		run; 

		%slicedata(stattable_sub,Race,trtLvlData,%sysfunc(pathname(work)),_SubDataList=sList);
		%NObsVars(trtLvlData);
		%let nsub = &nObs;
		%if &nsub <  &nv_race %then %do;
			%let nv_race=&nsub;
      	proc sort data =racesum;
      	by Race;
      	run;
      	proc sort data = trtLvlData;
      	by Race;
      	run;
      	data racesum;
      		merge racesum(in=a) trtLvlData(in=b);
      		by Race;
      		if b;
      	run;
      	%SortRowsByValueOrdering(racesum, Race);
      	%let _tid_=%sysfunc(open(racesum));
      	%do _i_ = 1 %to &nv_trt;
      	   %let _rc_=%sysfunc(fetchobs(&_tid_,&_i_));
      	   %let raceNameV&_i_ = %sysfunc(getvarc(&_tid_,%sysfunc(varnum(&_tid_,Race))));
      	   %let raceNameT&_i_ = %sysfunc(getvarn(&_tid_,%sysfunc(varnum(&_tid_,COUNT))));
      	   %*put i=&_i_ raceNameV=&&raceNameV&_i_ raceNameT&_i_=&&raceNameT&_i_ trtTotal=&trtTotal;
      	%end;
      	%let _tid_ = %sysfunc(close(&_tid_));
		%end;

      proc sort data=&OutData out = race_BST nodupkey;
         by AEBODSYS Race;
      run;		
		%slicedata(race_BST,Race,trtBslData,%sysfunc(pathname(work)),_SubDataList=sList);
	   %NObsVars(trtBslData);
	   %let bsobs=&nObs;
	   %do _i_ = 1 %to &bsobs;
	      %let _tid_=%sysfunc(open(race_BST&_i_));
	      %let nv_bs2&_i_  = %sysfunc(attrn(&_tid_,NOBS));
	      %do _j_ = 1 %to &&nv_bs2&_i_ ;
	         %let _rc_=%sysfunc(fetchobs(&_tid_,&_j_));
	         %let varnumber = %sysfunc(varnum(&_tid_,Race));
         	%let vartype = %sysfunc(vartype(&_tid_,&varnumber));
	         %let BodySysLvlV&_i_.&_j_ = %sysfunc(getvarc(&_tid_,%sysfunc(varnum(&_tid_,AEBODSYS))));
	         %let BodySysCount&_i_.&_j_ = %sysfunc(getvarn(&_tid_,%sysfunc(varnum(&_tid_,BodySys_count3))));
	         %if &vartype = C %then %let BodySysRace&_i_.&_j_ = %sysfunc(getvarc(&_tid_,%sysfunc(varnum(&_tid_,Race))));
	         %else %let BodySysRace&_i_.&_j_ = %sysfunc(getvarn(&_tid_,%sysfunc(varnum(&_tid_,Race))));
				%let BodySysRacePercent&_i_.&_j_ = %sysfunc(getvarn(&_tid_,%sysfunc(varnum(&_tid_,Percent_BSRace))));

	      %end;
	      %let _tid_ = %sysfunc(close(&_tid_));
	   %end;

	   %* handle cases when some races were filter out;
	   %let _tid_=%sysfunc(open(trtBslData));
	   %let nv_race2 = %sysfunc(attrn(&_tid_,NOBS)); 
	   %if &nv_race2 <  &nv_raceTmp %then %do;
	      %do _i_ = 1 %to &nv_race2;
	         %let _rc_=%sysfunc(fetchobs(&_tid_,&_i_));
	         %let varnumber = %sysfunc(varnum(&_tid_,Race));
	         %let vartype = %sysfunc(vartype(&_tid_,&varnumber));
	         %if &vartype = C %then %let raceNameV2&_i_ = %sysfunc(getvarc(&_tid_,%sysfunc(varnum(&_tid_,Race))));
	         %else %let raceNameV2&_i_ = %sysfunc(getvarn(&_tid_,%sysfunc(varnum(&_tid_,Race))));
	         %do _j_ = 1 %to &nv_raceTmp;
	            %if (%quote(%upcase(&&raceNameV2&_i_)) = %quote(%upcase(&&raceNameV&_j_)))  %then %do;
	               %let raceNameV2&_i_ = &&raceNameV&_j_;
	               %let raceNameT2&_i_ = &&raceNameT&_j_;
	               %put raceNameV2&_i_=&&raceNameV2&_i_ raceNameT2&_i_ =&&raceNameT2&_i_;
	            %end;
	         %end;
	      %end;
	      %do _i_ = 1 %to &nv_race2;
	         %let raceNameV&_i_ = &&raceNameV2&_i_;
	         %let raceNameT&_i_ = &&raceNameT2&_i_;
	      %end;
	   %end;
	   %let _tid_ = %sysfunc(close(&_tid_));
	   
	   * merge count and percent by AEDECOD/AETerm level for race; 
	   %do _i_ = 1 %to &nv_race;
	      %let raceNameLabel&_i_=&&raceNameV&_i_;
	      %let raceNameV&_i_=%sysfunc(translate(&&raceNameV&_i_,'_','.','_',' ','_','/','_','(','_',')','_',',','_','-'));
	      %if %length(&&raceNameV&_i_) <29 %then %let raceNameShort&_i_=&&raceNameV&_i_; 
	      %else %let raceNameShort&_i_=%substr(&&raceNameV&_i_,1,28);
	      %put raceNameV&_i_=&&raceNameV&_i_ raceNameShort&_i_=&&raceNameShort&_i_;
	      data stattable_sub&_i_;
	         length Gt1_raceName&_i_ $16 Pt1_raceName&_i_ $8;
	         set stattable_sub&_i_;
				Gt1_raceName&_i_ = group_count3;
				Pt1_raceName&_i_ = Percent_race;
            Gt1_raceName&_i_=trim(left(Gt1_raceName&_i_))||" ("||trim(left(Pt1_raceName&_i_))||")";
            label Gt1_raceName&_i_ =&&raceNameLabel&_i_;
            rename group_count3=group_count3&_i_ Percent_race=Percent_race&_i_;
      	run;
			proc sort data= stattable_sub&_i_;
	         by &AEDDtermVar;
	      run;
	      %if &_i_=1 %then %do;
	         data stattable_subR;
	            set stattable_sub&_i_;
	         run;
	      %end;
	      %else %do;
	         data stattable_subR;
	            merge stattable_subR(in=a) stattable_sub&_i_(in=b);
	            by &AEDDtermVar;
	            if a or b;
	         run;
	      %end;
	   %end;
         
	   data stattable_subR;
	      retain count_RaceTA 0;
	      set stattable_subR;
	      %do _i_ = 1 %to &nv_race;
	         %if &_i_ =1 %then %do;
	            if group_count3&_i_ =. then count_RaceTA=0;
	            else count_RaceTA=group_count3&_i_;
	         %end;
	         %else %do;
	            if group_count3&_i_ =. then count_RaceTA=count_RaceTA+0;
	            else count_RaceTA=count_RaceTA+group_count3&_i_;
	         %end;
	      %end;
	   run;

	   data stattable_subR;
	      length percent_Race $8 count_Race $16;
	      set stattable_subR;
	      count_Race =count_RaceTA; 
	      percent_RaceTA = round((count_RaceTA/&nsubjects)*100,0.1);
	      percent_Race=percent_RaceTA;  
	      count_Race =trim(left(count_Race))||" ("||trim(left(percent_Race))||")";
	      /*%do _i_ = 1 %to &nv_race;
	         if Pt1_&&raceNameV&_i_ < &PropThresh then delete;
	      %end;*/
	      if percent_RaceTA < &PropThresh then delete;
	      drop percent_RaceTA count_RaceTA;
	   run;

	   * get indent for AE events;
	   data stattable_subR;
	      set stattable_subR;
	      AEDDtermVar_pdf= %str("00"x)|| " " || &AEDDtermVar;
	      AEDDtermVar_text= %str('1E'x)|| " " || %str('1E'x)|| " " || %str('1E'x)|| &AEDDtermVar;
	      AEDDtermVar_rtf =%str('03'x) || " " ||%str('03'x) || " " || &AEDDtermVar ;       
	   run;

	   proc sort data =stattable_subR;
	      by AEBODSYS Race;
	   run;
               
	   %slicedata(stattable_subR,AEBODSYS,bsLvlData,%sysfunc(pathname(work)),_SubDataList=sList);
	   %NObsVars(bsLvlData);
	   %let nv_bodysystem = &nObs;
	         
	   *get the body system level;      
	   %do _i_ = 1 %to &nv_bodysystem;
	   
		   %let _tid_=%sysfunc(open(stattable_subR&_i_));
		   %let nv_trt2 = %sysfunc(attrn(&_tid_,NOBS)); 
		      %do _j_ = 1 %to &nv_trt2;
	         %let _rc_=%sysfunc(fetchobs(&_tid_,&_j_));
	         %let BodySysNameV = %sysfunc(getvarc(&_tid_,%sysfunc(varnum(&_tid_,AEBODSYS))));
	      %end;
	      %let _tid_ = %sysfunc(close(&_tid_));
	
	      %let bsSum=0;

	      %do _m_ = 1 %to &bsobs;
	         %let bsTotal&_m_=;
	         %do _n_ = 1 %to &&nv_bs2&_m_ ;
	            %if %qupcase(&&BodySysLvlV&_m_.&_n_) =%qupcase(&BodySysNameV) %then %do;
	               %let bsTotal&_m_=&&BodySysCount&_m_.&_n_; 
	               %let bsUID&_m_ =&&BodySysRacePercent&_m_.&_n_;
	               %*let bsUID&_m_ =%sysfunc(round(%sysevalf(&&BodySysCount&_m_.&_n_/&&raceNameT&_m_)*100,0.1));
	               %let bsSum=%eval(&bsSum+&&BodySysCount&_m_.&_n_);
	               %let bsRaceLvL&_m_ = &&BodySysRace&_m_.&_n_;
	               %let _n_= &&nv_bs2&_m_ ;
	            %end;
	         %end;
	      %end;
	            
	      %let bsUIDPerc=%sysfunc(round(%sysevalf(&bsSum/&RaceTotal)*100,0.1));
	               
	      data stattable_subRbs;
	         set stattable_subR&_i_;
	         if _n_=1 then do;
	            &AEDDtermVar = "&BodySysNameV";
	            AEDDtermVar_pdf="&BodySysNameV";
	            AEDDtermVar_text="&BodySysNameV";
	            AEDDtermVar_rtf="&BodySysNameV";
	            AEBODSYS=" ";
	            Sex =" ";
	            Race = " ";
	            COUNT =" ";
	            PERCENT =" ";
	            group_count =" ";
	            group_count1 =" ";
	            Percent_trt =" ";
	            group_count2 =" ";
	            Percent_sex=" ";
	            %do _j_ = 1 %to &nv_race;
	               Gt1_raceName&_j_=" ";
	               %if  %length(&&bsTotal&_j_) %then %do;
	                  Gt1_raceName&_j_= "&&bsTotal&_j_(&&bsUID&_j_)";
	               %end;
	               Pt1_raceName&_j_= " ";
	            %end;
	            count_Race = "&bsSum(&bsUIDPerc)";
	            percent_Race=" ";
	         end;
	         else delete;
	      run;
	      data stattable_subR&_i_;
	         set stattable_subRbs stattable_subR&_i_;
	      run;
	
	      %if &_i_=1 %then %do;
	         data stattable_subR;
	            set stattable_subR&_i_;
	         run;
	      %end;
	      %else %do;
	         data stattable_subR;
	            set stattable_subR stattable_subR&_i_;
	         run;
	      %end;
	   %end;
	         
	   data stattable_subRT;
	      set stattable_subR;
	         if _n_=1 then do;
	            &AEDDtermVar = "&trTotal";
	            AEDDtermVar_pdf="&trTotal";
	            AEDDtermVar_text="&trTotal";
	            AEDDtermVar_rtf="&trTotal";
	            AEBODSYS=" ";
	            Sex =" ";
	            Race = " ";
	            COUNT =" ";
	            PERCENT =" ";
	            group_count =" ";
	            group_count1 =" ";
	            Percent_trt =" ";
	            group_count2 =" ";
	            Percent_sex=" ";
	            %do _i_ = 1 %to &nv_race;
	               Gt1_raceName&_i_= "N=&&raceNameT&_i_";
	               Pt1_raceName&_i_= " ";
	            %end;
	            count_Race = "N=&RaceTotal";
	            percent_Race=" ";
	         end;
	         else delete;
	   run;
	   data stattable_subR;
	      set stattable_subRT stattable_subR;
	   run;
   %end;
	   
   %let SubjectFilterTmp = &trAllSubjects;
   %if %length(&PopulationSet) %then %do;
      %let SubjectFilterTmp = %nrbquote(%LocaleEZX(&PopulationSet, EIA=1));
      %if ^%index(%upcase(&PopulationSet),SUBJECTS) %then %let SubjectFilterTmp = %nrbquote(%LocaleFill(%nrbquote(%LocaleGet(XPopulation_Text)), f1=%nrbquote(&SubjectFilterTmp)));
   %end;
   %if %index(%upcase(&TEAEOnly),EMERGENT) %then %do;
      %let TEAEOnlyTmp =&trTreatmentEmergentAdvEvents;
   %end;
   %else %if %index(%upcase(&TEAEOnly),PRE) %then %do;
      %let TEAEOnlyTmp =&trPreTreatmentEvents;
   %end;
   %else %if %index(%upcase(&TEAEOnly),OFF) %then %do;
      %let TEAEOnlyTmp=&trOfftreatmentEvents with the offset for end of dosing as &TrtOffSet;
   %end;
   %else %if %index(%upcase(&TEAEOnly),ON) %then %do;
      %let TEAEOnlyTmp=&trOntreatmentEvents with the offset for end of dosing as &TrtOffSet;
   %end;
   %else %do;
      %let TEAEOnlyTmp =&trAllEventTypes;
   %end;
   
   * calculate a count table by severity or by casualty;
   %if &AESerCount = Yes %then %do;
      proc sort data=&OutData out=outtmp;
         by USUBJID;
      run;
      proc sort data=outdataSer;
         by USUBJID;
      run;

      %let aeserflag=0;    
      %let _ind_ = %sysfunc(open(outtmp));
      %let sevnum = %sysfunc(varnum(&_ind_,aesev));
      
      %if &sevnum>0 %then %do;
         %let aeserflag=1;
      %end;
      %let _ind_ = %sysfunc(close(&_ind_));
      
      %if &aeserflag=0 %then %do;
         data outdataSer;
            merge outtmp outdataSer;
         run;
      %end;
      %else %do;
         data outdataSer;
            set outtmp;
         run;        
      %end;
      %let _ind_ = %sysfunc(open(outdataSer));
      %let sevnum = %sysfunc(varnum(&_ind_,aetoxgrc));
      %if &sevnum=0 %then %do;
         %let toxgrnum = %sysfunc(varnum(&_ind_,aesev));
         %if &toxgrnum > 0 %then %let AeSev = sev;
      %end;
      %else %let AeSev = toxgrc;
      %let _ind_ = %sysfunc(close(&_ind_));
      
      data outdataSer;
         set outdataSer;
         if AE&AESEV='' or &trtName='' then delete;
      run;
      proc sort data=outdataSer(keep=AE&AESEV AEBODSYS &trtName AEDECOD) out=getcounts1;
         by AE&AESEV &trtName;
      run;  
      proc freq data=getcounts1 noprint;
         tables AEBODSYS *AEDECOD* &trtName*AE&AESEV  / out=countdt1;
      run;

      data countServ;
         set countdt1;
      run;
      * check if there is any severity levels for some treatment missing;
      proc sort data=outdataSer;
         by AE&AESEV;
      run;
      proc summary data=outdataSer;
         by AE&AESEV;
         output out=_p2;
      run;

      %nobsvars(_p2);
      %let ServNum=&nobs;
      %let tid = %sysfunc(open(_p2));  
      %do i=1 %to &ServNum;
         %let _rc_=%sysfunc(fetchobs(&tid,&i));
         %let servlevel&i =  %sysfunc(getvarc(&tid,%sysfunc(varnum(&tid,AE&AESEV))));
         %let servlevelunder&i=%sysfunc(translate(&&servlevel&i,%str(_),%str( )));
         %let servFlag&i=0;
         %put servlevel&i=&&servlevel&i;
      %end;
      %let tid = %sysfunc(close(&tid));
      
      * divide the main data by treatment level;
      %SliceData (countServ,&trtName,servlvl,%sysfunc(pathname(work)),_SubDataList=sList);  
      %nobsvars(servlvl);
      %let n1=&nobs;
      
      %let tid = %sysfunc(open(servlvl));
      %do i=1 %to &n1;
         %let _rc_=%sysfunc(fetchobs(&tid,&i));
         %let trtvar&i =  %sysfunc(getvarc(&tid,%sysfunc(varnum(&tid,&trtName))));
         %put trtvar&i=&&trtvar&i;
      %end;
      %let tid = %sysfunc(close(&tid));
      
      data severitylvl;
         set countServ;
      run;
      %SliceData (severitylvl,AE&AESEV,severitytable,%sysfunc(pathname(work)),_SubDataList=sList);
      %nobsvars(severitytable);
      %let n2=&nobs;
      
      %do i=1 %to &n1;
         *divide data by severity level;
         data countplacebo;
            set countserv&i;
         run;  
         %SliceData (countplacebo,AE&AESEV,servPlvl,%sysfunc(pathname(work)),_SubDataList=sList);
         %nobsvars(servPlvl);
         %let n3=&nobs;

         %if &n3<&n2 %then %do;

            data severitytable2;
               merge severitytable(in=ina) servPlvl(in=inb);
               by AE&AESEV;
               if ina and not inb;
            run;

            data countplacebo;
               set countplacebo severitytable2;
            run;

            %SliceData (countplacebo,AE&AESEV,servPlvl,%sysfunc(pathname(work)),_SubDataList=sList);

            %*put n1=&n1 n2=&n2 n3=&n3;
         %end;

         %let tid = %sysfunc(open(servPlvl));
         %do _j_=1 %to &n2;
            %let _rc_=%sysfunc(fetchobs(&tid,&_j_));
            %let sevvar&_j_ =  %sysfunc(getvarc(&tid,%sysfunc(varnum(&tid,AE&AESEV))));
            %let sevvarunder&_j_ = &&sevvar&_j_;
            %let sevvarunder&_j_=%sysfunc(translate(&&sevvar&_j_,%str(_),%str( )));
            %put sevvar&_j_=&&sevvarunder&_j_;
         %end; 
         %let tid = %sysfunc(close(&tid));
         
         *find missing severity level;
         %if &ServNum > &n2 %then %do;
            %do _sl_ = 1 %to &ServNum;
               %let servFlag&_sl_=0;
               %do _j_=1 %to &n2;
                  %if %nrbquote(&&servlevel&_sl_) = %nrbquote(&&sevvar&_j_) %then %do;
                     %let servFlag&_sl_=1;
                  %end;
               %end;
            %end;
         %end;

         %do j=1 %to &n2;
            data countplacebo&j;
               length count2 $6;
               set countplacebo&j;
               count2=count;
            run;
            data servsum1;
               set countplacebo&j;
               if _n_=1 then do;
                  count2="&&trtvar&i";
                  percent =.;
                  count =.;
               end;
               /*else if _n_=2 then do;
                  count2="&&sevvar&j";
                  percent =.;
                  count =.;
               end;*/
               else delete;
            run;
            data countplacebo&j;
               set countplacebo&j;
               rename Count2=sev&i._&j Percent=per&j;
               label Count2="sev&i.&&sevvarunder&j" Percent="per_&&sevvarunder&j";
               drop AE&AESEV  count;
            run;
            %if &j=1 & ^%sysfunc(fileexist(countServsum&i)) %then %do;
               data countServsum&i;
                  set countplacebo&j;
               run;
            %end;
            %else %do;
               proc sort data=countplacebo&j;
                  by AEBODSYS AEDECOD; 
               run;
               proc sort data=countServsum&i;
                  by AEBODSYS AEDECOD; 
               run;
      
               data countServsum&i;
                  merge countServsum&i countplacebo&j;
                  by AEBODSYS AEDECOD;
               run;
            %end;

         %end;
         
         * merge missing severity level in each treatment group;
         %if &servNum > &n2 %then %do;
            %do _sl_ = 1 %to &ServNum;
               %put servFlag=&&servFlag&_sl_;
               %if &&servFlag&_sl_=0 %then %do;
                  %let n2=%eval(&n2+1);
                  %let sevvarunder&n2 =&&servlevelunder&_sl_;
               
                  data servnum1(keep= AEBODSYS AEDECOD Count2);
                     length count2 $6;
                     set countServsum&i;
                     Count2=.;
                  run;
                  data servnum1;
                     set servnum1;
                     rename Count2=sev&i.&&servlevel&_sl_;
                  run;

                  %if ^%sysfunc(fileexist(countServsum&i)) %then %do;
                     data countServsum&i;
                        merge countServsum&i servnum1;
                        by AEBODSYS AEDECOD;
                     run;
                  %end;
                  %else %do;
                     data countServsum&i;
                        set servnum1;
                     run;
                  %end;
               %end;
            %end;
         %end;

         %if &i =1 %then %do;
            data countSerTotal;
               set countServsum&i;
            run;
         %end;
         %else %do;
            data countSerTotal;
               merge countSerTotal countServsum&i;
               by AEBODSYS AEDECOD;
            run;
         %end;
      %end;
      data countSerTotal;
         set countSerTotal;
         if AEBODSYS="" & AEDECOD="" then delete;
      run;
      
   %end;
  
   %if &Output_RTF = Yes %then %do;
      %if &Server = Local %then %do;
         ods rtf file="&ClientOutPath.\&OutName..rtf" bodytitle;
      %end;
      %else %if &Server ne Local %then %do;
         ods rtf file = "&ServerOutPath.\&OutName..rtf" bodytitle;
      %end;
      ods listing close;

      ods escapechar='^';
      options nobyline nodate missing = "" orientation = landscape;

      * calculate a count table by severity or by casualty;
      %if &AESerCount = Yes %then %do;

         PROC REPORT DATA=countserTotal %if %eval(&n1+&n2) >= 8 %then %do; style(column)=[fontsize=2 ]; %end;;
            COLUMN AEBODSYS AEDECOD ("&trtLabel" %do i=1 %to &n1; ("&&trtvar&i" (%do j=1 %to &ServNum; sev&i._&j %end;)) %end;)
               /* (%do i=1 %to &n1; ( %str("&&trtvar&i") (Mild Moderate Severe)) %end;)*/;
            %if %eval(&n1+&n2) > 5 & %eval(&n1+&n2) < 7 %then %do;
               DEFINE AEBODSYS / display FORMAT= $80. WIDTH=15 SPACING=2 LEFT " " order=data; 
               DEFINE AEDECOD / display FORMAT= $80. WIDTH=15 SPACING=2 LEFT " " order=data; 
            %end;
            %if %eval(&n1+&n2) > 6 %then %do;
               DEFINE AEBODSYS / display FORMAT= $80. WIDTH=10 SPACING=2 LEFT " " order=data; 
               DEFINE AEDECOD / display FORMAT= $80. WIDTH=10 SPACING=2 LEFT " " order=data; 
            %end;
            %else %do;
               DEFINE AEBODSYS / display FORMAT= $80. WIDTH=50 SPACING=2 LEFT " " order=data; 
               DEFINE AEDECOD / display FORMAT= $80. WIDTH=50 SPACING=2 LEFT " " order=data; 
            %end;
            **THE NO ZERO COMMAND IS USED SINCE ALL PRODUCT CATEGORIES WILL NOT BE
            REPRESENTED FOR EACH PRODUCT LINE IN THE TABLE;
            %do i=1 %to &n1;
               *  DEFINE %str(&&trtvar&i) / display "&&trtvar&i" width=20 ;
               *  define TRT01P /across;
               %do j=1 %to &n2;
                  %if %eval(&n1+&n2) > 5 & %eval(&n1+&n2) <= 6 %then %do;
                     DEFINE sev&i._&j  /display "&&sevvar&j" width=4 style(column)=[cellwidth=6%];
                  %end;
                  %else %if %eval(&n1+&n2) > 6 & %eval(&n1+&n2) < 8 %then %do;
                     DEFINE sev&i._&j  /display "&&sevvar&j" width=4 style(column)=[cellwidth=5%];
                  %end;
                  %else %if %eval(&n1+&n2) >= 8 %then %do;
                     DEFINE sev&i._&j  /display "&&sevvar&j" width=3 style(column)=[cellwidth=4%] ;
                  %end;
                  %else %do;
                     DEFINE sev&i._&j  /display "&&sevvar&j" width=20  ;
                  %end;
               %end;
            %end;
            title1 height=17pt "&trAdvEvCtBySevLev";
         RUN;  
      %end;
   
      * get the proportion and occurrence report for trt;
      %if %length(&trtLabel) and %upcase(&TrtUse) ne NONE and &T_trtNameP_flag ^= 0 %then %do;
         %let trtMaxLen=0;
         %do i=1 %to &nv_trt;
            %let trtLen&i=%length(&&trtNameLabel&i);
            %if &trtMaxLen < &&trtLen&i %then %do;
               %let trtMaxLen=&&trtLen&i;
            %end;
         %end;

         proc report data = stattable_subt LS=97  PS=54  SPLIT="#" CENTER nowindows missing Contents="&trAETrtPropReport";
            column AEDDtermVar_rtf  ("&trtLabel" %do i=1 %to &nv_trt; ("%nrbquote(&&trtNameLabel&i)" GT1_trtName&i) %end;("&trTotal" Count_trt));
            define AEDDtermVar_rtf / display FORMAT= $80. WIDTH=70 SPACING=3 LEFT " " order=data; 
         
            %do i=1 %to &nv_trt;
               %if &trtMaxLen >45 & &nv_trt < 5 %then %do;
                  define GT1_trtName&i / display "&trCount (%)"  WIDTH=20  style(column)=[cellwidth=30%] ;
               %end;
               %else %do;
                  define GT1_trtName&i / display "&trCount (%)"  WIDTH=20;
               %end;
         *      define Pt1_&&trtNameV&i / display "&trPercent"  WIDTH=20  ;
            %end;
            define Count_trt / display "&trCount (%)"  WIDTH=20  ;

            title1 height=17pt "&trAEEvOccAndPropRepforTrt";
            %if &PropThresh>0 %then %do;
            %let trRepEvWithALOPTOcc = %nrbquote(%LocaleFill(&trReportingEvWithALOvXOcc, &PropThresh));
               title2 height=17pt "&trRepEvWithALOPTOcc";
            %end;
            %else %do;
               title2 height=17pt "&trReportingAllEvents";
            %end;
            %if %upcase(&AESerOnly)=YES %then %do;
               %let trTIncSAEOforSFTC = %nrbquote(%LocaleFill(&trXIncSerAEOnlyforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
               title3 height=12pt "&StudyName: &trTIncSAEOforSFTC";
            %end;
            %else %do;
               %let trTforSFTC = %nrbquote(%LocaleFill(&trXforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
               title3 height=12pt "&StudyName: &trTforSFTC";
            %end;
         run;
      %end;
      
      %if &sexflag %then %do;
         proc report data = stattable_subS LS=97  PS=54  SPLIT="/" CENTER  nowindows missing Contents="&trAESexPropReport";
            column AEDDtermVar_rtf  ("&trSex" %do i=1 %to &nv_sex; ("%nrbquote(&&sexNameLabel&i)" GT1_sexName&i) %end;("&trTotal" Count_sex));
            
            define AEDDtermVar_rtf / display FORMAT= $80. WIDTH=70 SPACING=2 LEFT " " order=data; 
            %do i=1 %to &nv_sex;
                define GT1_sexName&i / display "&trCount (%)"  WIDTH=20  ;
          *     define Pt1_&&sexNameV&i / display "&trPercent"  WIDTH=20  ;
            %end;
            define Count_sex / display "&trCount (%)"  WIDTH=20  ;   

            title1 height=17pt "&trAEEvOccAndPropRepforSex";
            %if &PropThresh>0 %then %do;
               %let trRepEvWithALOPTOcc = %nrbquote(%LocaleFill(&trReportingEvWithALOvXOcc, &PropThresh));
               title2 height=17pt "&trRepEvWithALOPTOcc";
            %end;
            %else %do;
               title2 height=17pt "&trReportingAllEvents";
            %end;
            %if %upcase(&AESerOnly)=YES %then %do;
               %let trTIncSAEOforSFTC = %nrbquote(%LocaleFill(&trXIncSerAEOnlyforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
               title3 height=12pt "&trTIncSAEOforSFTC";
            %end;
            %else %do;
               %let trTforSFTC = %nrbquote(%LocaleFill(&trXforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
               title3 height=12pt "&trTforSFTC";
            %end;
         run;
      %end;
      %if &raceflag %then %do;
         proc report data = stattable_subR LS=97  PS=54  SPLIT="/" CENTER  nowindows missing Contents="&trAERacePropReport";
            column AEDDtermVar_rtf  ("&trRace" %do i=1 %to &nv_race; ("%nrbquote(&&raceNameLabel&i)" GT1_raceName&i) %end;("&trTotal" Count_Race));
                
            %if &nv_race >5 %then %do;
               define AEDDtermVar_rtf / display  FORMAT= $80. WIDTH=70 style(column)=[cellwidth=15%] SPACING=2 LEFT " " order=data; 
               %do i=1 %to &nv_race;
                   define GT1_raceName&i / display "&trCount (%)"  WIDTH=13 style(column)=[cellwidth=10%] ;
            *      define Pt1_&&raceNameV&i / display "&trPercent (%)"  WIDTH=20  ;
               %end;
               define Count_Race / display "&trCount (%)"  WIDTH=15  ;
            %end;
            %else %do;
               define AEDDtermVar_rtf / display  FORMAT= $80. WIDTH=70 SPACING=2 LEFT " " order=data; 
               %do i=1 %to &nv_race;
                   define GT1_raceName&i / display "&trCount (%)"  WIDTH=20  ;
            *      define Pt1_&&raceNameV&i / display "&trPercent (%)"  WIDTH=20  ;
               %end;
               define Count_Race / display "&trCount (%)"  WIDTH=20  ;
            %end;
   
            title1 height=17pt "&trAEEvOccAndPropRepforRace";
            %if &PropThresh>0 %then %do;
               %let trRepEvWithALOPTOcc = %nrbquote(%LocaleFill(&trReportingEvWithALOvXOcc, &PropThresh));
               title2 height=17pt "&trRepEvWithALOPTOcc";
            %end;
            %else %do;
               title2 height=17pt "&trReportingAllEvents";
            %end;
            %if %upcase(&AESerOnly)=YES %then %do;
               %let trTIncSAEOforSFTC = %nrbquote(%LocaleFill(&trXIncSerAEOnlyforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
               title3 height=12pt "&trTIncSAEOforSFTC";
            %end;
            %else %do;
               %let trTforSFTC = %nrbquote(%LocaleFill(&trXforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
               title3 height=12pt "&trTforSFTC";
            %end;
         run; 
      %end;

         ods rtf close;
         %if &syserr > 4 %then %goto exit;
      %end;
      %if &Output_PDF = Yes %then %do;
         %if &Server = Local %then %do;
            ods pdf file="&ClientOutPath.\&OutName..pdf" ;
         %end;
         %else %if &Server ne Local %then %do;
            ods pdf file="&ServerOutPath.\&OutName..pdf" ;
         %end;
         ods listing close;
         ods escapechar='^';
         options nobyline nodate missing = "" orientation = landscape;

         * calculate a count table by severity or by casualty;
         %if &AESerCount = Yes %then %do;
            PROC REPORT DATA=countserTotal ;
               COLUMN AEBODSYS AEDECOD ("&trtLabel" %do i=1 %to &n1; ("&&trtvar&i" (%do j=1 %to &n2; sev&i._&j %end;)) %end;)/* (%do i=1 %to &n1; ( %str("&&trtvar&i") (Mild Moderate Severe)) %end;)*/;
               %if %eval(&n1+&n2) > 5 %then %do;
                  DEFINE AEBODSYS / display FORMAT= $80. WIDTH=15 SPACING=2 LEFT " " order=data; 
                  DEFINE AEDECOD / display FORMAT= $80. WIDTH=15 SPACING=2 LEFT " " order=data; 
               %end;
               %else %do;              
                  DEFINE AEBODSYS / display FORMAT= $80. WIDTH=80 SPACING=2 LEFT " " order=data; 
                  DEFINE AEDECOD / display FORMAT= $80. WIDTH=80 SPACING=2 LEFT " " order=data; 
               %end;
               **THE NO ZERO COMMAND IS USED SINCE ALL PRODUCT CATEGORIES WILL NOT BE
               REPRESENTED FOR EACH PRODUCT LINE IN THE TABLE;
               %do i=1 %to &n1;
                  *  DEFINE %str(&&trtvar&i) / display "&&trtvar&i" width=20 ;
                  *  define TRT01P /across;
                  %do j=1 %to &n2;
                     %if %eval(&n1+&n2) > 5 %then %do;
                        DEFINE sev&i._&j  /display "&&sevvar&j" width=4 style(column)=[cellwidth=6%];
                     %end;
                     %else %do;
                        DEFINE sev&i._&j  /display "&&sevvar&j" width=20  ;
                     %end;
                  %end;
               %end;
               title1 height=17pt "&trAdvEvCtBySevLev";
            RUN;  
         %end;    
         * get the proportion and occurrence report for trt;
         %if %length(&trtLabel) and %upcase(&TrtUse) ne NONE and &T_trtNameP_flag ^= 0 %then %do;
            proc report data = stattable_subt LS=97  PS=54  SPLIT="/" CENTER  nowindows missing Contents="&trAETrtPropReport";

               column AEDDtermVar_pdf  ("&trtLabel" %do i=1 %to &nv_trt; ("%nrbquote(&&trtNameLabel&i)" GT1_trtName&i) %end;("&trTotal" Count_trt));
               define AEDDtermVar_pdf / display FORMAT= $80. WIDTH=80 SPACING=2 LEFT " " order=data; 
            
               %do i=1 %to &nv_trt;
                define GT1_trtName&i / display "&trCount (%)"  WIDTH=20  ;
           *    define Pt1_&&trtNameV&i / display "&trPercent (%)"  WIDTH=20  ;
               %end;
               define Count_trt / display "&trCount (%)"  WIDTH=20  ;

               title1 height=17pt "&trAEEvOccAndPropRepforTrt";
               %if &PropThresh>0 %then %do;
                  %let trRepEvWithALOPTOcc = %nrbquote(%LocaleFill(&trReportingEvWithALOvXOcc, &PropThresh));
                  title2 height=17pt "&trRepEvWithALOPTOcc";
               %end;
               %else %do;
                  title2 height=17pt "&trReportingAllEvents";
               %end;
               %if %upcase(&AESerOnly)=YES %then %do;
                  %let trTIncSAEOforSFTC = %nrbquote(%LocaleFill(&trXIncSerAEOnlyforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
                  title3 height=12pt "&trTIncSAEOforSFTC";
               %end;
               %else %do;
                  %let trTforSFTC = %nrbquote(%LocaleFill(&trXforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
                  title3 height=12pt "&trTforSFTC";
               %end;
            run;
         %end;

         %if &sexflag %then %do;
            proc report data = stattable_subS LS=97  PS=54  SPLIT="/" CENTER  nowindows missing Contents="&trAESexPropReport";
               column AEDDtermVar_pdf  ("&trSex" %do i=1 %to &nv_sex; ("%nrbquote(&&sexNameLabel&i)" GT1_sexName&i) %end;("&trTotal" Count_sex ));
               define AEDDtermVar_pdf / display FORMAT= $80. WIDTH=80 SPACING=2 LEFT " " order=data; 
               
               %do i=1 %to &nv_sex;
                define GT1_sexName&i / display "&trCount (%)"  WIDTH=20  ;
          *     define Pt1_&&sexNameV&i / display "&trPercent (%)"  WIDTH=20  ;
               %end;
               define Count_sex / display "&trCount (%)"  WIDTH=20  ;   
   
               title1 height=17pt "&trAEEvOccAndPropRepforSex";
               %if &PropThresh>0 %then %do;
                  %let trRepEvWithALOPTOcc = %nrbquote(%LocaleFill(&trReportingEvWithALOvXOcc, &PropThresh));
                  title2 height=17pt "&trRepEvWithALOPTOcc";
               %end;
               %else %do;
                  title2 height=17pt "&trReportingAllEvents";
               %end;
               %if %upcase(&AESerOnly)=YES %then %do;
                  %let trTIncSAEOforSFTC = %nrbquote(%LocaleFill(&trXIncSerAEOnlyforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
                  title3 height=12pt "&trTIncSAEOforSFTC";
               %end;
               %else %do;
                  %let trTforSFTC = %nrbquote(%LocaleFill(&trXforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
                  title3 height=12pt "&trTforSFTC";
               %end;
            run;
         %end;
         %if &raceflag %then %do;
            proc report data = stattable_subR LS=97  PS=54  SPLIT="/" CENTER  nowindows missing Contents="&trAERacePropReport";
               column AEDDtermVar_pdf  ("&trRace" %do i=1 %to &nv_race; ("%nrbquote(&&raceNameLabel&i)" GT1_raceName&i ) %end;("&trTotal" Count_Race ));
               define AEDDtermVar_pdf / display FORMAT= $80. WIDTH=80 SPACING=2 LEFT " " order=data; 
                  
               %do i=1 %to &nv_race;
                define GT1_raceName&i / display "&trCount (%)"  WIDTH=20  ;
           *    define Pt1_&&raceNameV&i / display "&trPercent (%)"  WIDTH=20  ;
               %end;
               define Count_Race / display "&trCount (%)"  WIDTH=20  ;

               title1 height=17pt "&trAEEvOccAndPropRepforRace";
               %if &PropThresh>0 %then %do;
                  %let trRepEvWithALOPTOcc = %nrbquote(%LocaleFill(&trReportingEvWithALOvXOcc, &PropThresh));
                  title2 height=17pt "&trRepEvWithALOPTOcc";
               %end;
               %else %do;
                  title2 height=17pt "&trReportingAllEvents";
               %end;
               %if %upcase(&AESerOnly)=YES %then %do;
                  %let trTIncSAEOforSFTC = %nrbquote(%LocaleFill(&trXIncSerAEOnlyforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
                  title3 height=12pt "&trTIncSAEOforSFTC";
               %end;
               %else %do;
                  %let trTforSFTC = %nrbquote(%LocaleFill(&trXforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
                  title3 height=12pt "&trTforSFTC";
               %end;
            run; 
         %end;

         ods pdf close;
         %if &syserr > 4 %then %goto exit;
      %end;
         
      %if &Output_HTML = Yes %then %do;
         %PrepHTML(
            AEDistributionReport_Body, 
            AEDistributionReport_Frame, 
            AEDistributionReport_Contents, 
            &OutName._body.html, 
            &OutName._frame.html, 
            &OutName._contents.html
         );       
         ods html 
            body = "&AEDistributionReport_Body" (url="&bodyfile")
               frame = "&AEDistributionReport_Frame"  (url="&framefile")
               contents = "&AEDistributionReport_Contents" (url="&contentsfile")
            ;
            
            * calculate a count table by severity or by casualty;
            %if &AESerCount = Yes %then %do;
               PROC REPORT DATA=countserTotal ;
                  COLUMN AEBODSYS AEDECOD ("&trtLabel" %do i=1 %to &n1; ("&&trtvar&i" (%do j=1 %to &n2; sev&i._&j %end;)) %end;)/* (%do i=1 %to &n1; ( %str("&&trtvar&i") (Mild Moderate Severe)) %end;)*/;
                  %if %eval(&n1+&n2) > 5 %then %do;
                     DEFINE AEBODSYS / display FORMAT= $80. WIDTH=15 SPACING=2 LEFT " " order=data; 
                     DEFINE AEDECOD / display FORMAT= $80. WIDTH=15 SPACING=2 LEFT " " order=data; 
                  %end;
                  %else %do;
                     DEFINE AEBODSYS / display FORMAT= $80. WIDTH=80 SPACING=2 LEFT " " order=data; 
                     DEFINE AEDECOD / display FORMAT= $80. WIDTH=80 SPACING=2 LEFT " " order=data; 
                  %end;
                  **THE NO ZERO COMMAND IS USED SINCE ALL PRODUCT CATEGORIES WILL NOT BE
                  REPRESENTED FOR EACH PRODUCT LINE IN THE TABLE;
                  %do i=1 %to &n1;
                     *  DEFINE %str(&&trtvar&i) / display "&&trtvar&i" width=20 ;
                     *  define TRT01P /across;
                     %do j=1 %to &n2;
                        %if %eval(&n1+&n2) > 5 %then %do;
                           DEFINE sev&i._&j  /display "&&sevvar&j" width=4 style(column)=[cellwidth=6%];
                        %end;
                        %else %do;
                           DEFINE sev&i._&j  /display "&&sevvar&j" width=20  ;
                        %end;
                     %end;
                  %end;
                  title1 height=17pt "&trAdvEvCtBySevLev";
               RUN;  
            %end; 
            %if %length(&trtLabel) and %upcase(&TrtUse) ne NONE and &T_trtNameP_flag ^= 0 %then %do;
               proc report data = stattable_subt LS=97  PS=54  SPLIT="/" CENTER  nowindows missing Contents="&trAETrtPropReport";
                  column AEDDtermVar_text  ("&trtLabel" %do i=1 %to &nv_trt; ("%nrbquote(&&trtNameLabel&i)" GT1_trtName&i) %end;("&trTotal" Count_trt));
                  define AEDDtermVar_text / display FORMAT= $80. WIDTH=70 SPACING=2 LEFT " " order=data; 
            
                  %do i=1 %to &nv_trt;
                   define GT1_trtName&i / display "&trCount (%)"  WIDTH=20  ;
               *      define Pt1_&&trtNameV&i / display "&trPercent"  WIDTH=20  ;
                  %end;
                  define Count_trt / display "&trCount (%)"  WIDTH=20  ;

                  title1 height=17pt "&trAEEvOccAndPropRepforTrt";
                  %if &PropThresh>0 %then %do;
                     %let trRepEvWithALOPTOcc = %nrbquote(%LocaleFill(&trReportingEvWithALOvXOcc, &PropThresh));
                     title2 height=17pt "&trRepEvWithALOPTOcc";
                  %end;
                  %else %do;
                     title2 height=17pt "&trReportingAllEvents";
                  %end;    
                  %if %upcase(&AESerOnly)=YES %then %do;
                     %let trTIncSAEOforSFTC = %nrbquote(%LocaleFill(&trXIncSerAEOnlyforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
                     title3 height=12pt "&trTIncSAEOforSFTC";
                  %end;
                  %else %do;
                     %let trTforSFTC = %nrbquote(%LocaleFill(&trXforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
                     title3 height=12pt "&trTforSFTC";
                  %end;
               run;
            %end;
            %if &sexflag %then %do;
               proc report data = stattable_subS LS=97  PS=54  SPLIT="/" CENTER  nowindows missing Contents="&trAESexPropReport";
                  column AEDDtermVar_text  ("&trSex" %do i=1 %to &nv_sex; ("%nrbquote(&&sexNameLabel&i)" GT1_sexName&i) %end;("&trTotal" Count_sex));
               
                  define AEDDtermVar_text / display FORMAT= $80. WIDTH=70 SPACING=2 LEFT " " order=data; 
                  %do i=1 %to &nv_sex;
                   define GT1_sexName&i / display "&trCount (%)"  WIDTH=20  ;
                *     define Pt1_&&sexNameV&i / display "&trPercent"  WIDTH=20  ;
                  %end;
                  define Count_sex / display "&trCount (%)"  WIDTH=20  ;

                  title1 height=17pt "&trAEEvOccAndPropRepforSex";
                  %if &PropThresh>0 %then %do;
                     %let trRepEvWithALOPTOcc = %nrbquote(%LocaleFill(&trReportingEvWithALOvXOcc, &PropThresh));
                     title2 height=17pt "&trRepEvWithALOPTOcc";
                  %end;
                  %else %do;
                     title2 height=17pt "&trReportingAllEvents";
                  %end;
                  %if %upcase(&AESerOnly)=YES %then %do;
                     %let trTIncSAEOforSFTC = %nrbquote(%LocaleFill(&trXIncSerAEOnlyforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
                     title3 height=12pt "&trTIncSAEOforSFTC";
                  %end;
                  %else %do;
                     %let trTforSFTC = %nrbquote(%LocaleFill(&trXforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
                     title3 height=12pt "&trTforSFTC";
                  %end;
               run;
            %end;

            %if &raceflag %then %do;
               proc report data = stattable_subR LS=97  PS=54  SPLIT="/" CENTER  nowindows missing Contents="&trAERacePropReport";
                  column AEDDtermVar_text  ("&trRace" %do i=1 %to &nv_race; ("%nrbquote(&&raceNameLabel&i)" GT1_raceName&i) %end;("&trTotal" Count_Race));
                  
                  define AEDDtermVar_text / display FORMAT= $80. WIDTH=70 SPACING=2 LEFT " " order=data; 
                  %do i=1 %to &nv_race;
                   define GT1_raceName&i / display "&trCount (%)"  WIDTH=20  ;
               *      define Pt1_&&raceNameV&i / display "&trPercent (%)"  WIDTH=20  ;
                  %end;
                  define Count_Race / display "&trCount (%)"  WIDTH=20  ;
   
                  title1 height=17pt "&trAEEvOccAndPropRepforRace";
                  %if &PropThresh>0 %then %do;
                     %let trRepEvWithALOPTOcc = %nrbquote(%LocaleFill(&trReportingEvWithALOvXOcc, &PropThresh));
                     title2 height=17pt "&trRepEvWithALOPTOcc";
                  %end;
                  %else %do;
                     title2 height=17pt "&trReportingAllEvents";
                  %end;
                  %if %upcase(&AESerOnly)=YES %then %do;
                     %let trTIncSAEOforSFTC = %nrbquote(%LocaleFill(&trXIncSerAEOnlyforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
                     title3 height=12pt "&trTIncSAEOforSFTC";
                  %end;
                  %else %do;
                     %let trTforSFTC = %nrbquote(%LocaleFill(&trXforXChosen, f1=%nrbquote(&TEAEOnlyTmp), f2=%nrbquote(&SubjectFilterTmp)));
                     title3 height=12pt "&trTforSFTC";
                  %end;
               run; 
            %end;
            ods html close;
            %if &syserr > 4 %then %goto mexit;
         %end;
         %if &Output_Text = Yes %then %do;
            %if &Server = Local %then %do;
               ods listing file="&ClientOutPath.\&OutName..lst";
            %end;
            %else %if &Server ne Local %then %do;
               ods listing file="&ServerOutPath.\&OutName..lst";
            %end;
               ods escapechar='^';
               options nobyline nodate missing = "" orientation = landscape;
         
               * get the proportion and occurrence report for trt;
            %if %length(&trtLabel) and %upcase(&TrtUse) ne NONE %then %do;
               proc report data = stattable_subt LS=97  PS=54  SPLIT="/" CENTER  nowindows missing Contents="&trAETrtPropReport";
                  column AEDDtermVar_text  ("&trtLabel" %do i=1 %to &nv_trt; ("%nrbquote(&&trtNameLabel&i)" GT1_trtName&i ) %end;("&trTotal" Count_trt));
                  define AEDDtermVar_text / display FORMAT= $80. WIDTH=70 SPACING=2 LEFT " " order=data; 
               
                  %do i=1 %to &nv_trt;
                   define GT1_trtName&i / display "&trCount (%)"  WIDTH=20  ;
                *     define Pt1_&&trtNameV&i / display "&trPercent (%)"  WIDTH=20  ;
                  %end;
                  define Count_trt / display "&trCount (%)"  WIDTH=20  ;
                  title1 "&trAEEvOccAndPropRepforTrt";
                  %if &PropThresh>0 %then %do;
                     %let trRepEvWithALOPTOcc = %nrbquote(%LocaleFill(&trReportingEvWithALOvXOcc, &PropThresh));
                     title2 "&trRepEvWithALOPTOcc";
                  %end;
                  %else %do;
                     title2 "&trReportingAllEvents";
                  %end;
               run;
            %end;
            %if &sexflag %then %do;
               proc report data = stattable_subS LS=97  PS=54  SPLIT="/" CENTER  nowindows missing Contents="&trAESexPropReport";
                  column AEDDtermVar_text  ("&trSex" %do i=1 %to &nv_sex; ("%nrbquote(&&sexNameLabel&i)" GT1_sexName&i) %end;("&trTotal" Count_sex));
                  define AEDDtermVar_text / display FORMAT= $80. WIDTH=70 SPACING=2 LEFT " " order=data; 
                  
                  %do i=1 %to &nv_sex;
                   define GT1_sexName&i / display "&trCount (%)"  WIDTH=20  ;
            *      define Pt1_&&sexNameV&i / display "&trPercent (%)"  WIDTH=20  ;
                  %end;
                  define Count_sex / display "&trCount (%)"  WIDTH=20  ;            
                  title1 "&trAEEvOccAndPropRepforSex";
                  %if &PropThresh>0 %then %do;
                     %let trRepEvWithALOPTOcc = %nrbquote(%LocaleFill(&trReportingEvWithALOvXOcc, &PropThresh));
                     title2 "&trRepEvWithALOPTOcc";
                  %end;
                  %else %do;
                     title2 "&trReportingAllEvents";
                  %end;
               run;
            %end;
            %if &raceflag %then %do;
               proc report data = stattable_subR LS=97  PS=54  SPLIT="/" CENTER  nowindows missing Contents="&trAERacePropReport";
                  column AEDDtermVar_text  ("&trRace" %do i=1 %to &nv_race; ("%nrbquote(&&raceNameLabel&i)" GT1_raceName&i) %end;("&trTotal" Count_Race));
                  define AEDDtermVar_text / display FORMAT= $80. WIDTH=70 SPACING=2 LEFT " " order=data; 
                  
                  %do i=1 %to &nv_race;
                   define GT1_raceName&i / display "&trCount (%)"  WIDTH=20  ;
               *      define Pt1_&&raceNameV&i / display "&trPercent (%)"  WIDTH=20  ;
                  %end;
                  define Count_Race / display "&trCount (%)"  WIDTH=20  ;  
                  title1 "&trAEEvOccAndPropRepforRace";
                  %if &PropThresh>0 %then %do;
                     %let trRepEvWithALOPTOcc = %nrbquote(%LocaleFill(&trReportingEvWithALOvXOcc, &PropThresh));
                     title2 "&trRepEvWithALOPTOcc";
                  %end;
                  %else %do;
                     title2 "&trReportingAllEvents";
                  %end;
               run; 
            %end;
            ods listing close;
         %end;
         %else %if &Output_Text = No %then %do;
            ods listing close;
         %end;
         %if &Output_Text = Yes %then %do;
            ods listing close;
         %end; 
   %if &exiterror=1 %then %goto exit;

   * create JSL file;
   %PrepOutFile(AdverseEventsReportScript,AdverseEventsReportScriptName,&StudyName &ProcessName Script.jsl);
   %global _mainjslfile_ FullAPName;
   %let _mainjslfile_ = &AdverseEventsReportScript;
   %let FullAPName = Adverse Events Report;
   %if &Server^=Local %then %do;
      %let FullOutName = &ClientOutPath.&OutName;  
      %let OutPath2 = &ClientOutPath;
   %end;
   %else %do;
      %let OutPath2 = &OutPath;
   %end;
   
   %let trAEReport = %nrbquote(%LocaleGet(AdverseEventSummaryReport_Text));
   %let trOpen = %nrbquote(%LocaleGet(Open_Text));

   filename jslfile "&_mainjslfile_";
   data _null_;
      file jslfile %if %nrbquote(&SYSENCODING) ne wlatin1 %then encoding="utf-8";;
      put '//!';
      put "Names Default to Here(1);";
      put "objRefNS = newnamespace();";
      put "jg:currentObjRefNamespaceName = objRefNS << getName;";        
      put "objRefNS:DataList = {};";
      put "objRefNS:TabButtonList = {};";
      put "objRefNS:TabCodeList = {};";
      put "objRefNS:TabAfterCodeList = {};";
      put "objRefNS:TabOpenList = {};";
      put "objRefNS:CreateReportList = {};";  
      put "objRefNS:ShowDataTables = 0;";
      put "objRefNS:ShowCreateReport = 0;";
      put "objRefNS:ShowNotes = 0;";   
      put "objRefNS:fbox=Function({},{default local},";
      put "   Vlistbox(";
      %if %length(&TEAEText) %then %do;
         put "objRefNS:TEAEText = TextBox(""&TEAEText"", <<Set Wrap(1000)), Text Box(""""),";
      %end;
      %let _fCount_ = 0;
      %if &Output_RTF = Yes %then %do;
         %let _fCount_ = %eval(&_fCount_+1);
         %let _fList_ = &OutName..rtf;
         put "      objRefNS:Button1=ButtonBox(""&trOpen &trAEReport..rtf"",";
         put "          Open(""&ClientOutPath.&OutName..rtf"");";
         put "      ),";
         put "      objRefNS:Button1 << Underline Style(1),";   
      %end;
      %if &Output_PDF = Yes %then %do;
         %let _fCount_ = %eval(&_fCount_+1);
         %if &_fCount_ = 1 %then %do;
            %let _fList_ = &OutName..pdf;
         %end;
         %else %do;
            %let _fList_ = &_fList_,&OutName..pdf;
         %end;
         put "      objRefNS:Button2=ButtonBox(""&trOpen &trAEReport..pdf"",";
         put "          Open(""&ClientOutPath.&OutName..pdf"");";
         put "      ),";
         put "      objRefNS:Button2 << Underline Style(1),";   
      %end;
      %if &Output_HTML = Yes %then %do;
         %let _fCount_ = %eval(&_fCount_+1);
         %if &_fCount_ = 1 %then %do;
            %let _fList_ = "&bodyfile,&framefile,&contentsfile";
         %end;
         %else %do;
            %let _fList_ = &_fList_,&bodyfile,&framefile,&contentsfile;
         %end;
         put "      objRefNS:Button2=ButtonBox(""&trOpen &trAEReport..html"",";
         put "          Web(""&ClientOutPath.&framefile"");";
         put "      ),";
         put "      objRefNS:Button2 << Underline Style(1),";   
      %end;
      put "   )";
      put ");";   
      %if &_fCount_ > 1 %then %do;
         %let _fList_ = "&_fList_";
      %end;
      put "InsertInto(objRefNS:DataList,{{""  ""}});";
      put "InsertInto(objRefNS:TabButtonList, Expr(locale:get(""AdverseEventSummaryReport_Text"")));";
      put "InsertInto(objRefNS:TabCodeList,expr(objRefNS:fbox()));";
      put "InsertInto(objRefNS:TabAfterCodeList, "" "");";
      put "InsertInto(objRefNS:CreateReportList,{{objRefNS:TEAEText}});";
      put "InsertInto(objRefNS:TabOpenList,1);";    
   run;
   
   %PackageInsertFile(jsl code from &ProcessName, &OutPath, &AdverseEventsReportScriptName,&_fList_,
      text/plain, yes);

   %exit:;
   %ExitSDSProcess(&OutPath, &ProcessName, &syserr, &exiterror, &clockrunning);

%mend AdverseEventsReport;

* run the macro;
%AdverseEventsReport;


