
/************************ PRODUCT VALIDATION  ******************
 *
 *      NAME: AdverseEventsDistribution_AE002.sas
 *    REPORT: Adverse Event Distribution JMPC7.1
 *   PURPOSE: Adverse Event Distribution Validation Program for Nicardipine Study
 *   DEFECTS: 
 *     NOTES: Use Dictornary-Derived Term,BodySystem or Organ Class, 
 *     NOTES: Use Actual Treatment, All event types , count multiple occurrences of an event per subject
 *	   NOTES: Use Calculate Incidence Rates for adverse event occurrences, Patient Years of Exposure, 100 Patient Years Multiplier, Date Variables
 *     NOTES: NO Discrepancy found between JMPC Results and Validation Results

 *****************************************************************/
title1 'AdverseEventsDistribution_AE002.sas: Adverse Event Distribution Validation Program - Incidence Rates';
title2 'Use BodySystem or Organ Class, Actual, All event, count multiple occurrences, incidence rates, patient years of exposure, multiplier 100, date variables';

libname sdtm "&SDTMPATH";
libname adam "&ADAMPATH";

data adsl;
 set adam.adsl;
 if saffl='Y' and trt01p ne 'Screen Failure';
 if trt01p ne '' then do; trtsrt=trt01p; output; end;
 if trt01p ne '' then do; trtsrt='Total'; output; end;
run;

data ae;
 set sdtm.ae;
run;

data ae_adsl;
 merge adam.adsl(in=a where=(saffl='Y' and trt01p ne 'Screen Failure')) ae(in=b);
 by usubjid;
 if a & b;

 if trt01p ne '' then do; trtsrt=trt01p; output; end;
 if trt01p ne '' then do; trtsrt='Total'; output; end;
run;

*** IR Calculations - Exposure ***;
data py_exp;
 set adam.adsl;
 if saffl='Y' and arm ne 'Screen Failure';
 startdy = trtsdtm/60/60/24;
 enddy = trtedtm/60/60/24;
 py_exp = (enddy - startdy + 1);
run;

proc sort data=py_exp; by arm; run;
proc means data = py_exp;
 by arm;
 var py_exp;
 output out=py_exp_sum sum=sum;
run;

data py_exp_sum;
 set py_exp_sum;
 sum2=sum/365.25;
run;

data _null_;
 set py_exp_sum;
 if arm='NIC .15' then call symput('NIC',sum2);
 else call symput(arm,sum2);
run;

*** Number of events for IR calculation ***;
*** Get Tabulate counts/percents ***;
data events0;
 set ae_adsl;
 date = put(input(scan(aestdtc,1,'T'),yymmdd10.),date9.);
 time = scan(aestdtc,-1,'T');
 date_time = input(date||':'||time,datetime19.);
 format date_time datetime19.;

 if .<trtsdtm<=date_time<=trtedtm;
run;

proc sort data=events0 out=events;
 by trtsrt usubjid aebodsys aedecod;
run;

proc freq data=events noprint;
 by trtsrt;
 tables aebodsys*aedecod/out=freq_events(drop=percent);
run;

data freq_events2;
 merge freq_events py_exp_sum(rename=(arm=trtsrt));
 by trtsrt;
 nper=put(count,3.);
 ir=put((count*100)/sum2,6.1);
run;

proc sort data=freq_events2; by aebodsys aedecod; run;
proc transpose data=freq_events2 out=t_freq_events1;
 by aebodsys aedecod;
 var nper;
 id trtsrt;
run; 

proc transpose data=freq_events2 out=t_freq_events2;
 by aebodsys aedecod;
 var ir;
 id trtsrt;
run; 

data t_freq_events;
 merge t_freq_events1(rename=(nic__15=nic15_count placebo=placebo_count)) t_freq_events2(drop=total rename=(nic__15=nic15_ir placebo=placebo_ir));
 by aebodsys aedecod;
 drop _name_;
run;

**** Use Proc Report to write the lab stats Tables to file;
options nodate nonumber missing = ' ';

filename pdfOutF "&OUTPUTD/AdverseEventsDistribution_AE002.pdf";

ods escapechar='#';
ods pdf style =htmlblue file=pdfOutF;

proc report data=t_freq_events
	nowindows
	split="|";
	
	columns aebodsys aedecod ("NIC.15 (PY=&nic)" Nic15_count Nic15_IR) ("Placebo (PY=&placebo)" Placebo_count Placebo_IR) Total;

	define aebodsys /order width =14 "Body System or Organ Class";
	define aedecod  /order width =14 "Dictionary-Derived Term";
	define Nic15_count  /display center width=14 "Count";
	define Nic15_IR /display center width=14 "IR/100PY";
	define Placebo_count  /display center width=14 "Count";
	define Placebo_IR /display center width=14 "IR/100PY";
	define Total    /display center width=14 "Total";

	compute after aebodsys;
		line '#{newline}';
	endcomp;

title3 j=c 'Adverse Events Distribution Incidence Rates Table';
run;

ods pdf close;

*** Dataset to use for distributions ***;
data ae_dist;
 merge adam.adsl(in=a where=(saffl='Y' and trt01p ne 'Screen Failure')) events0(where=(trtsrt ne 'Total'));
 by usubjid;
 if a;
run;

proc sort data=ae_dist out=dists;
 by trt01p usubjid aebodsys aedecod descending aeser descending aesev aestdy;
run;

libname outdata "&OUTPUTD";
data outdata.AdverseEventsDistribution_AE002;
 set dists(keep=trt01p usubjid aebodsys aedecod aeser aesev aestdy aerel aeacn aeout);
run;
