
/************************ PRODUCT VALIDATION  ******************
 *
 *      NAME: DiscontinuationTimetoEvent_DS001.sas
 *    REPORT: Discontinuation Time to Event JMPC 7.1
 *   PURPOSE: Discontinuation Time to Event Validation Program for Nicardipine study
 *     NOTES: Use Actual treatment, Discon due to all reasons, first event
 *     Notes: Define Events as Dsicontinuations due to Adverse events or deaths, SAFETY POPULATION
 *     NOTES: Same Results as JMPC for Nicardipine study 
 *****************************************************************/
title1 'DiscontinuationTimetoEvent_DS001.sas: Discontinuation Time to Event Validation Program';
title2 'Use Actual treatment, Discontinuations due to adverse events or deaths';


libname sdtm "&SDTMPATH";
libname adam "&ADAMPATH";

data adsl;
 set adam.adsl;
 where saffl='Y' and trt01p ne 'Screen Failure';
run;

data dm;
 set sdtm.dm (keep=usubjid RFSTDTC RFENDTC);
run;

data adsl; merge adsl (in=inadsl) dm;
 by usubjid;
 if inadsl;
run;

**** obs in ds with disposition event ;
data ds; set sdtm.ds (drop=domain studyid);
 where upcase(DSCAT)='DISPOSITION EVENT';
run;

data ds ; set ds;
 by usubjid;
 if last.usubjid=1;
run;

**** adsl  merge with ds information**;
data adsl_ds; 
 merge adsl(in=in1) ds(in=in2 keep=usubjid dsstdtc dsdecod dscat dsstdy);
 by usubjid;
 inadsl=in1;
 inds=in2;
 if inadsl;
run;

proc freq data=ds;
 tables dsdecod;
run;

 **** if not in DS then use censor cutoff date=rfendtc;
data adsl_ds_time;
set adsl_ds;
if inds=1 then 
do;
    if DSDECOD="DEATH" or DSDECOD="ADVERSE EVENT" then
	do;
     	atime = input(dsstdtc,yymmdd10.)- input(rfstdtc,yymmdd10.)+1;
		CNSR=0; failed=1;
	end;
    else do;
  	 atime= input(dsstdtc,yymmdd10.)- input(rfstdtc,yymmdd10.)+1;
   	 CNSR=1; failed=0; 
	end;
end;

if inds =0 then 
   do;
   atime = input(rfendtc,yymmdd10.)- input(rfstdtc,yymmdd10.)+1;
   CNSR=1; failed=0;
   end;
run;

*** check contingency table**;
*** correct JMPC table ***;
*** Mosaic plot  ***;
ods listing gpath="&OUTPUTD";
ods graphics on;
proc freq data=adsl_ds_time;
 tables failed*trt01p / chisq plots=MOSAIC;
run;


ods output CensoredSummary=events;
ods output HomTests=teststats;
ods output Means=means;
ods output Quartiles=quartiles;
ods output ProductLimitEstimates=estimate;

proc lifetest data=adsl_ds_time method=pl plots=survival(cb atrisk);
 Time atime*CNSR(1);
 strata trt01p / test=logrank wilcoxon;
run;

ods listing close;

proc print data=teststats;
run;

*** PROC PHREG ***;
ods output HazardRatios=hr;
proc phreg data=adsl_ds_time;
 class trt01p(ref="Placebo");
 model atime*cnsr(1)=trt01p;
 hazardratio trt01p/ diff=ref;
run;
