
/************************ PRODUCT VALIDATION ******************
 *
 *      NAME: EventsDistribution_MH001.sas
 *    REPORT: Events distribution JMPC 7.1
 *   PURPOSE: MH Events distributyion Validation Program for Nicardipine study
 *   DEFECTS: 
 *     NOTES: Use Dictionary-Derived Term, Actual treatment
 *     Notes: All event type, SAFETY POPULATION
 *     NOTES: Same Results as JMPC for Nicardipine study 
 *****************************************************************/
title1 'EventsDistribution_MH001.sas: Medical History distribution Validation Program';
title2 'Use Actual treatment, All event type, safety population';


libname sdtm "&SDTMPATH";
libname adam "&ADAMPATH";

data adsl;
 set adam.adsl;
 where saffl='Y' and trt01p ne 'Screen Failure';
run;

data dm;
	set sdtm.dm (keep=usubjid RFSTDTC RFENDTC);
run;

data adsl; merge adsl (in=inadsl) dm;
by usubjid;
if inadsl;
run;

**** 4105 obs in ds;
data mh; set sdtm.mh (keep=usubjid mhdecod MHBODSYS );
run;


**** Perform a simple count of each treatment arm and output results;
**** N1= 1st column N for Placebo;
**** N2= 2nd column N for Active Therapy,
**** N3= 3rd column N for Total N;


**** Perform a simple count of each treatment arm and output results;
**** N1= 1st column N for Placebo;
**** N2= 2nd column N for Active Therapy,
**** N3= 3rd column N for Total N;


proc sql noprint;
	select count(distinct usubjid) format=3.
		into :n1
		from adsl
		where trt01pn=0;
    select count(distinct usubjid) format=3.
		into :n2
		from adsl
		where trt01pn=1;
	select count(distinct usubjid) format=3.
		into :n3
		from adsl
		where trt01pn ne .;
quit;


**** Merge Medical History and treatment data;
proc sql;
	create table mh_adsl as
		select  unique (c.mhdecod) as mhdecod, c.usubjid, c.mhbodsys,
         a.trt01pn 
		 from mh as c, adsl as a
		 where c.usubjid=a.usubjid
		 order by usubjid, mhdecod;
quit;


proc sql;
	create table MH_code as
	select unique mhdecod ,mhbodsys
	from mh_adsl
	order by mhdecod;
quit;

**** Get MH Counts by Treatment and Place in Dataset;

ods listing close;

ods  output CrossTabFreqs=counts;
proc freq 
	data=mh_adsl ;
		tables trt01pn*mhdecod;
		run;


proc sort data=counts; by mhdecod;
run;

data mh_counts;
 merge counts(where=(trt01pN=0) rename =(frequency = count1))
 		counts(where=(trt01pN=1) rename =(frequency = count2))
		counts (where=(trt01pN=.) rename =(frequency = count3))
		end=eof;
		by mhdecod;
		keep mhdecod rowlabel col1-col3 section;
		length rowlabel $25 col1-col3 $ 10;
        if mhdecod='' then
			do;
				rowlabel = "ANY MHDECOD";
				section =1;
			end;
		else
		do;
		rowlabel = MHdecod;
			section =2;
		end;
		
		pct1=(count1/&&n1)*100;
		pct2=(count2/&&n2)*100;
		pct3=(count3/&&n3)*100;

		col1= put(count1, 4.) || "(" || put(pct1, 3.) || "%)";
		col2= put(count2, 4.) || "(" || put(pct2, 3.) || "%)";
		col3= put(count3, 4.) || "(" || put(pct3, 3.) || "%)";
run;


data mh_counts; merge mh_counts mh_code;
by mhdecod;
if mhbodsys =' ' then section1=2;
else section1=1;
if section=1 then section1=0;
run;



proc sort data=mh_counts;
by section1 section mhbodsys mhdecod;
run;


**** Use Proc Report to write the MH Tables to file;

options nodate nonumber missing = ' ';

filename pdfOutF "&OUTPUTD/MedicalHistory_001.pdf";

ods escapechar='#';
ods pdf style =htmlblue file=pdfOutF;

proc report data=mh_counts
	nowindows
	split="|";
	
	columns  section1 section mhbodsys rowlabel col2 col1 col3;

  
    define section /order noprint;
    define section1/order noprint;
	define mhbodsys /order order= data display center "Body System or Organ Class" width=20 ;
	define rowlabel / display width =25 "Dictoionary-Derived Term";
	define col1 	/display center width=14 "Placebo | N= &n1";
	define col2		/display center width=14 "Active  | N= &n2";
	define col3 	/display center width=14 "Total | N= &n3";

	compute after section;
		line '#{newline}';
	endcomp;

title3 j=c 'Summary of Medical History By treatment ';
run;

ods pdf close;
