
/************************ PRODUCT VALIDATION  ******************
 *
 *      NAME: InterventionsDistribution_CM001.sas
 *    REPORT: Concomitant Medications distribution JMPC 7.1
 *   PURPOSE: Concomitant Medications Distribution Validation Program for Nicardipine study
 *   DEFECTS: 
 *     NOTES: All types,  Actual treatment, Single Count CM
 *     Notes: SAFETY POPULATION
 *     NOTES: Same Results as JMPC for Nicardipine study 
 *****************************************************************/
title1 'InterventionsDistribution_CM001.sas: CM distribution Validation Program';
title2 'Use Actual treatment, single count CM';


libname sdtm "&SDTMPATH";
libname adam "&ADAMPATH";

data adsl;
 set adam.adsl;
 where saffl='Y' and trt01p ne 'Screen Failure';
run;


data cm; set sdtm.cm (keep=usubjid cmcat cmdecod);
run;

**** Perform a simple count of each treatment arm and output results;
**** N1= 1st column N for Placebo;
**** N2= 2nd column N for Active Therapy,
**** N3= 3rd column N for Total N;


proc sql noprint;
	select count(distinct usubjid) format=3.
		into :n1
		from adsl
		where trt01pn=0;
    select count(distinct usubjid) format=3.
		into :n2
		from adsl
		where trt01pn=1;
	select count(distinct usubjid) format=3.
		into :n3
		from adsl
		where trt01pn ne .;
quit;




**** Merge concomitant medications and treatment data;
proc sql;
	create table cm_adsl as
		select unique (c.cmdecod) as cmdecod, c.usubjid, c.cmcat,
         a.trt01pn 
		 from cm as c, adsl as a
		 where c.usubjid=a.usubjid
		 order by usubjid, cmcat, cmdecod;
quit;

proc sql;
 	create table cmcat_cod as
	select unique (cmdecod) as cmdecod, cmcat from cm
	order by cmdecod;
run;

data cmcat_cod; set cmcat_cod;
 	if cmcat ="" then cmcat="Missing";
run;

**** Get Medication Counts by Treatment and Place in Dataset;

ods listing close;

ods  output CrossTabFreqs=counts;
proc freq 
	data=cm_adsl ;
		tables trt01pn *cmdecod;
		run;

ods output close;
ods listing;

proc sort data=counts;
by cmdecod;
run;


data counts_CM;
 merge counts(where=(trt01pN=0) rename =(frequency = count1))
 		counts(where=(trt01pN=1) rename =(frequency = count2))
		counts (where=(trt01pN=.) rename =(frequency = count3))
		end=eof;
		by cmdecod;
		keep cmdecod rowlabel col1-col3 section;
		length rowlabel $25 col1-col3 $ 14;
        if cmdecod='' then
			do;
				rowlabel = "ANY MEDICATION";
				section =1;
			end;
		else
		do;
		rowlabel = cmdecod;
			section =2;
		end;
		
		pct1=(count1/&&n1)*100;
		pct2=(count2/&&n2)*100;
		pct3=(count3/&&n3)*100;

		col1= put(count1, 4.) || "(" || put(pct1, 4.1) || "%)";
		col2= put(count2, 4.) || "(" || put(pct2, 4.1) || "%)";
		col3= put(count3, 4.) || "(" || put(pct3, 4.1) || "%)";
run;

proc sort data=counts_CM ;
by cmdecod;
run;

data inreport; merge cmcat_cod counts_CM;
by cmdecod;
if cmcat="Missing" then section=3;
if rowlabel = "ANY MEDICATION" then cmcat="All";
run;

proc sort data=inreport;
by section cmcat rowlabel;
run;

**** Use Proc Report to write the conmed Tables to file;
options nodate nonumber missing = ' ';

filename pdfOutF "&OUTPUTD/SummaryOfConcomitantMedication.pdf";

ods escapechar='#';
ods pdf style =htmlblue file=pdfOutF;

proc report data=inreport
	nowindows
	split="|";
	
	columns section cmcat rowlabel col2 col1 col3;

	define section /order order=internal noprint;
	define cmcat /order  width=25 order=internal "Category for Medication";
	define rowlabel /order  width =25 "Standardized Medication Name";
	define col1 	/display center width=16 "Placebo | N= &n1";
	define col2		/display center width=16 "NIC .15  | N= &n2";
	define col3 	/display center width=16 "Total | N= &n3";

	compute after section;
		line '#{newline}';
	endcomp;

title3 j=c 'Summary of Concomitant Medications';
run;
ods pdf close;
